"""
Python module generated from Java source file org.bukkit.Utility

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import *
from typing import Any, Callable, Iterable, Tuple


class Utility:
    """
    This annotation indicates a method (and sometimes constructor) will chain
    its internal operations.
    
    This is solely meant for identifying methods that don't need to be
    overridden / handled manually.
    """





"""
Python module generated from Java source file com.google.common.base.Strings

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import VisibleForTesting
from com.google.common.base import *
from com.google.errorprone.annotations import InlineMe
from com.google.errorprone.annotations import InlineMeValidationDisabled
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class Strings:
    """
    Static utility methods pertaining to `String` or `CharSequence` instances.

    Author(s)
    - Kevin Bourrillion

    Since
    - 3.0
    """

    @staticmethod
    def nullToEmpty(string: str) -> str:
        """
        Returns the given string if it is non-null; the empty string otherwise.

        Arguments
        - string: the string to test and possibly return

        Returns
        - `string` itself if it is non-null; `""` if it is null
        """
        ...


    @staticmethod
    def emptyToNull(string: str) -> str:
        """
        Returns the given string if it is nonempty; `null` otherwise.

        Arguments
        - string: the string to test and possibly return

        Returns
        - `string` itself if it is nonempty; `null` if it is empty or null
        """
        ...


    @staticmethod
    def isNullOrEmpty(string: str) -> bool:
        """
        Returns `True` if the given string is null or is the empty string.
        
        Consider normalizing your string references with .nullToEmpty. If you do, you can
        use String.isEmpty() instead of this method, and you won't need special null-safe forms
        of methods like String.toUpperCase either. Or, if you'd like to normalize "in the other
        direction," converting empty strings to `null`, you can use .emptyToNull.

        Arguments
        - string: a string reference to check

        Returns
        - `True` if the string is null or is the empty string
        """
        ...


    @staticmethod
    def padStart(string: str, minLength: int, padChar: str) -> str:
        """
        Returns a string, of length at least `minLength`, consisting of `string` prepended
        with as many copies of `padChar` as are necessary to reach that length. For example,
        
        
          - `padStart("7", 3, '0')` returns `"007"`
          - `padStart("2010", 3, '0')` returns `"2010"`
        
        
        See java.util.Formatter for a richer set of formatting capabilities.

        Arguments
        - string: the string which should appear at the end of the result
        - minLength: the minimum length the resulting string must have. Can be zero or negative, in
            which case the input string is always returned.
        - padChar: the character to insert at the beginning of the result until the minimum length
            is reached

        Returns
        - the padded string
        """
        ...


    @staticmethod
    def padEnd(string: str, minLength: int, padChar: str) -> str:
        """
        Returns a string, of length at least `minLength`, consisting of `string` appended
        with as many copies of `padChar` as are necessary to reach that length. For example,
        
        
          - `padEnd("4.", 5, '0')` returns `"4.000"`
          - `padEnd("2010", 3, '!')` returns `"2010"`
        
        
        See java.util.Formatter for a richer set of formatting capabilities.

        Arguments
        - string: the string which should appear at the beginning of the result
        - minLength: the minimum length the resulting string must have. Can be zero or negative, in
            which case the input string is always returned.
        - padChar: the character to append to the end of the result until the minimum length is
            reached

        Returns
        - the padded string
        """
        ...


    @staticmethod
    def repeat(string: str, count: int) -> str:
        """
        Returns a string consisting of a specific number of concatenated copies of an input string. For
        example, `repeat("hey", 3)` returns the string `"heyheyhey"`.
        
        **Java 11+ users:** use `string.repeat(count)` instead.

        Arguments
        - string: any non-null string
        - count: the number of times to repeat it; a nonnegative integer

        Returns
        - a string containing `string` repeated `count` times (the empty string if
            `count` is zero)

        Raises
        - IllegalArgumentException: if `count` is negative
        """
        ...


    @staticmethod
    def commonPrefix(a: "CharSequence", b: "CharSequence") -> str:
        """
        Returns the longest string `prefix` such that `a.toString().startsWith(prefix) &&
        b.toString().startsWith(prefix)`, taking care not to split surrogate pairs. If `a` and
        `b` have no common prefix, returns the empty string.

        Since
        - 11.0
        """
        ...


    @staticmethod
    def commonSuffix(a: "CharSequence", b: "CharSequence") -> str:
        """
        Returns the longest string `suffix` such that `a.toString().endsWith(suffix) &&
        b.toString().endsWith(suffix)`, taking care not to split surrogate pairs. If `a` and
        `b` have no common suffix, returns the empty string.

        Since
        - 11.0
        """
        ...


    @staticmethod
    def lenientFormat(template: str, *args: Tuple["Object", ...]) -> str:
        ...



from .FixedMetadataValue import FixedMetadataValue
from .MetadataValue import MetadataValue
from .LazyMetadataValue import LazyMetadataValue
from .MetadataStoreBase import MetadataStoreBase
from .MetadataConversionException import MetadataConversionException
from .MetadataValueAdapter import MetadataValueAdapter
from .MetadataStore import MetadataStore
from .MetadataEvaluationException import MetadataEvaluationException
from .Metadatable import Metadatable


"""
Python module generated from Java source file org.bukkit.entity.Ageable

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class Ageable(Creature):
    """
    Represents an entity that can age.
    """

    def getAge(self) -> int:
        """
        Gets the age of this mob.

        Returns
        - Age
        """
        ...


    def setAge(self, age: int) -> None:
        """
        Sets the age of this mob.

        Arguments
        - age: New age
        """
        ...


    def setAgeLock(self, lock: bool) -> None:
        """
        Lock the age of the animal, setting this will prevent the animal from
        maturing or getting ready for mating.

        Arguments
        - lock: new lock

        Deprecated
        - see Breedable.setAgeLock(boolean)
        """
        ...


    def getAgeLock(self) -> bool:
        """
        Gets the current agelock.

        Returns
        - the current agelock

        Deprecated
        - see Breedable.getAgeLock()
        """
        ...


    def setBaby(self) -> None:
        """
        Sets the age of the mob to a baby
        """
        ...


    def setAdult(self) -> None:
        """
        Sets the age of the mob to an adult
        """
        ...


    def isAdult(self) -> bool:
        """
        Returns True if the mob is an adult.

        Returns
        - return True if the mob is an adult
        """
        ...


    def canBreed(self) -> bool:
        """
        Return the ability to breed of the animal.

        Returns
        - the ability to breed of the animal

        Deprecated
        - see Breedable.canBreed()
        """
        ...


    def setBreed(self, breed: bool) -> None:
        """
        Set breedability of the animal, if the animal is a baby and set to
        breed it will instantly grow up.

        Arguments
        - breed: breedability of the animal

        Deprecated
        - see Breedable.setBreed(boolean)
        """
        ...



"""
Python module generated from Java source file com.google.common.base.Objects

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.base import *
from java.util import Arrays
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class Objects(ExtraObjectsMethodsForWeb):
    """
    Helper functions that can operate on any `Object`.
    
    See the Guava User Guide on <a
    href="https://github.com/google/guava/wiki/CommonObjectUtilitiesExplained">writing `Object`
    methods with `Objects`</a>.

    Author(s)
    - Laurence Gonsalves

    Since
    - 2.0
    """

    @staticmethod
    def equal(a: "Object", b: "Object") -> bool:
        """
        Determines whether two possibly-null objects are equal. Returns:
        
        
          - `True` if `a` and `b` are both null.
          - `True` if `a` and `b` are both non-null and they are equal according to
              Object.equals(Object).
          - `False` in all other situations.
        
        
        This assumes that any non-null objects passed to this function conform to the `equals()` contract.
        
        **Note:** this method is now unnecessary and should be treated as deprecated; use java.util.Objects.equals instead.
        """
        ...


    @staticmethod
    def hashCode(*objects: Tuple["Object", ...]) -> int:
        """
        Generates a hash code for multiple values. The hash code is generated by calling Arrays.hashCode(Object[]). Note that array arguments to this method, with the exception of a
        single Object array, do not get any special handling; their hash codes are based on identity
        and not contents.
        
        This is useful for implementing Object.hashCode(). For example, in an object that
        has three properties, `x`, `y`, and `z`, one could write:
        
        ````public int hashCode() {
          return Objects.hashCode(getX(), getY(), getZ());`
        }```
        
        **Warning:** When a single object is supplied, the returned hash code does not equal the
        hash code of that object.
        
        **Note:** this method is now unnecessary and should be treated as deprecated; use java.util.Objects.hash instead.
        """
        ...



"""
Python module generated from Java source file java.nio.file.FileSystemException

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import IOException
from java.nio.file import *
from typing import Any, Callable, Iterable, Tuple


class FileSystemException(IOException):

    def __init__(self, file: str):
        """
        Constructs an instance of this class. This constructor should be used
        when an operation involving one file fails and there isn't any additional
        information to explain the reason.

        Arguments
        - file: a string identifying the file or `null` if not known.
        """
        ...


    def __init__(self, file: str, other: str, reason: str):
        """
        Constructs an instance of this class. This constructor should be used
        when an operation involving two files fails, or there is additional
        information to explain the reason.

        Arguments
        - file: a string identifying the file or `null` if not known.
        - other: a string identifying the other file or `null` if there
                 isn't another file or if not known
        - reason: a reason message with additional information or `null`
        """
        ...


    def getFile(self) -> str:
        """
        Returns the file used to create this exception.

        Returns
        - the file (can be `null`)
        """
        ...


    def getOtherFile(self) -> str:
        """
        Returns the other file used to create this exception.

        Returns
        - the other file (can be `null`)
        """
        ...


    def getReason(self) -> str:
        """
        Returns the string explaining why the file system operation failed.

        Returns
        - the string explaining why the file system operation failed
        """
        ...


    def getMessage(self) -> str:
        """
        Returns the detail message string.
        """
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.parser.VersionTagsTuple

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml.DumperOptions import Version
from org.yaml.snakeyaml.parser import *
from typing import Any, Callable, Iterable, Tuple


class VersionTagsTuple:
    """
    Store the internal state for directives
    """

    def __init__(self, version: "Version", tags: dict[str, str]):
        ...


    def getVersion(self) -> "Version":
        ...


    def getTags(self) -> dict[str, str]:
        ...


    def toString(self) -> str:
        ...



"""
Python module generated from Java source file java.util.concurrent.atomic.AtomicBoolean

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.lang.invoke import MethodHandles
from java.lang.invoke import VarHandle
from java.util.concurrent.atomic import *
from typing import Any, Callable, Iterable, Tuple


class AtomicBoolean(Serializable):
    """
    A `boolean` value that may be updated atomically. See the
    VarHandle specification for descriptions of the properties
    of atomic accesses. An `AtomicBoolean` is used in
    applications such as atomically updated flags, and cannot be used
    as a replacement for a java.lang.Boolean.

    Author(s)
    - Doug Lea

    Since
    - 1.5
    """

    def __init__(self, initialValue: bool):
        """
        Creates a new `AtomicBoolean` with the given initial value.

        Arguments
        - initialValue: the initial value
        """
        ...


    def __init__(self):
        """
        Creates a new `AtomicBoolean` with initial value `False`.
        """
        ...


    def get(self) -> bool:
        """
        Returns the current value,
        with memory effects as specified by VarHandle.getVolatile.

        Returns
        - the current value
        """
        ...


    def compareAndSet(self, expectedValue: bool, newValue: bool) -> bool:
        """
        Atomically sets the value to `newValue`
        if the current value `== expectedValue`,
        with memory effects as specified by VarHandle.compareAndSet.

        Arguments
        - expectedValue: the expected value
        - newValue: the new value

        Returns
        - `True` if successful. False return indicates that
        the actual value was not equal to the expected value.
        """
        ...


    def weakCompareAndSet(self, expectedValue: bool, newValue: bool) -> bool:
        """
        Possibly atomically sets the value to `newValue`
        if the current value `== expectedValue`,
        with memory effects as specified by VarHandle.weakCompareAndSetPlain.

        Arguments
        - expectedValue: the expected value
        - newValue: the new value

        Returns
        - `True` if successful

        See
        - .weakCompareAndSetPlain

        Deprecated
        - This method has plain memory effects but the method
        name implies volatile memory effects (see methods such as
        .compareAndExchange and .compareAndSet).  To avoid
        confusion over plain or volatile memory effects it is recommended that
        the method .weakCompareAndSetPlain be used instead.
        """
        ...


    def weakCompareAndSetPlain(self, expectedValue: bool, newValue: bool) -> bool:
        """
        Possibly atomically sets the value to `newValue`
        if the current value `== expectedValue`,
        with memory effects as specified by VarHandle.weakCompareAndSetPlain.

        Arguments
        - expectedValue: the expected value
        - newValue: the new value

        Returns
        - `True` if successful

        Since
        - 9
        """
        ...


    def set(self, newValue: bool) -> None:
        """
        Sets the value to `newValue`,
        with memory effects as specified by VarHandle.setVolatile.

        Arguments
        - newValue: the new value
        """
        ...


    def lazySet(self, newValue: bool) -> None:
        """
        Sets the value to `newValue`,
        with memory effects as specified by VarHandle.setRelease.

        Arguments
        - newValue: the new value

        Since
        - 1.6
        """
        ...


    def getAndSet(self, newValue: bool) -> bool:
        """
        Atomically sets the value to `newValue` and returns the old value,
        with memory effects as specified by VarHandle.getAndSet.

        Arguments
        - newValue: the new value

        Returns
        - the previous value
        """
        ...


    def toString(self) -> str:
        """
        Returns the String representation of the current value.

        Returns
        - the String representation of the current value
        """
        ...


    def getPlain(self) -> bool:
        """
        Returns the current value, with memory semantics of reading as
        if the variable was declared non-`volatile`.

        Returns
        - the value

        Since
        - 9
        """
        ...


    def setPlain(self, newValue: bool) -> None:
        """
        Sets the value to `newValue`, with memory semantics
        of setting as if the variable was declared non-`volatile`
        and non-`final`.

        Arguments
        - newValue: the new value

        Since
        - 9
        """
        ...


    def getOpaque(self) -> bool:
        """
        Returns the current value,
        with memory effects as specified by VarHandle.getOpaque.

        Returns
        - the value

        Since
        - 9
        """
        ...


    def setOpaque(self, newValue: bool) -> None:
        """
        Sets the value to `newValue`,
        with memory effects as specified by VarHandle.setOpaque.

        Arguments
        - newValue: the new value

        Since
        - 9
        """
        ...


    def getAcquire(self) -> bool:
        """
        Returns the current value,
        with memory effects as specified by VarHandle.getAcquire.

        Returns
        - the value

        Since
        - 9
        """
        ...


    def setRelease(self, newValue: bool) -> None:
        """
        Sets the value to `newValue`,
        with memory effects as specified by VarHandle.setRelease.

        Arguments
        - newValue: the new value

        Since
        - 9
        """
        ...


    def compareAndExchange(self, expectedValue: bool, newValue: bool) -> bool:
        """
        Atomically sets the value to `newValue` if the current value,
        referred to as the *witness value*, `== expectedValue`,
        with memory effects as specified by
        VarHandle.compareAndExchange.

        Arguments
        - expectedValue: the expected value
        - newValue: the new value

        Returns
        - the witness value, which will be the same as the
        expected value if successful

        Since
        - 9
        """
        ...


    def compareAndExchangeAcquire(self, expectedValue: bool, newValue: bool) -> bool:
        """
        Atomically sets the value to `newValue` if the current value,
        referred to as the *witness value*, `== expectedValue`,
        with memory effects as specified by
        VarHandle.compareAndExchangeAcquire.

        Arguments
        - expectedValue: the expected value
        - newValue: the new value

        Returns
        - the witness value, which will be the same as the
        expected value if successful

        Since
        - 9
        """
        ...


    def compareAndExchangeRelease(self, expectedValue: bool, newValue: bool) -> bool:
        """
        Atomically sets the value to `newValue` if the current value,
        referred to as the *witness value*, `== expectedValue`,
        with memory effects as specified by
        VarHandle.compareAndExchangeRelease.

        Arguments
        - expectedValue: the expected value
        - newValue: the new value

        Returns
        - the witness value, which will be the same as the
        expected value if successful

        Since
        - 9
        """
        ...


    def weakCompareAndSetVolatile(self, expectedValue: bool, newValue: bool) -> bool:
        """
        Possibly atomically sets the value to `newValue` if the current
        value `== expectedValue`,
        with memory effects as specified by
        VarHandle.weakCompareAndSet.

        Arguments
        - expectedValue: the expected value
        - newValue: the new value

        Returns
        - `True` if successful

        Since
        - 9
        """
        ...


    def weakCompareAndSetAcquire(self, expectedValue: bool, newValue: bool) -> bool:
        """
        Possibly atomically sets the value to `newValue` if the current
        value `== expectedValue`,
        with memory effects as specified by
        VarHandle.weakCompareAndSetAcquire.

        Arguments
        - expectedValue: the expected value
        - newValue: the new value

        Returns
        - `True` if successful

        Since
        - 9
        """
        ...


    def weakCompareAndSetRelease(self, expectedValue: bool, newValue: bool) -> bool:
        """
        Possibly atomically sets the value to `newValue` if the current
        value `== expectedValue`,
        with memory effects as specified by
        VarHandle.weakCompareAndSetRelease.

        Arguments
        - expectedValue: the expected value
        - newValue: the new value

        Returns
        - `True` if successful

        Since
        - 9
        """
        ...



"""
Python module generated from Java source file com.google.common.primitives.ImmutableDoubleArray

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.base import Preconditions
from com.google.common.primitives import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.errorprone.annotations import Immutable
from java.io import Serializable
from java.util import AbstractList
from java.util import Arrays
from java.util import RandomAccess
from java.util import Spliterator
from java.util.function import DoubleConsumer
from java.util.stream import DoubleStream
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class ImmutableDoubleArray(Serializable):
    """
    An immutable array of `double` values, with an API resembling List.
    
    Advantages compared to `double[]`:
    
    
      - All the many well-known advantages of immutability (read *Effective Java*, third
          edition, Item 17).
      - Has the value-based (not identity-based) .equals, .hashCode, and .toString behavior you expect.
      - Offers useful operations beyond just `get` and `length`, so you don't have to
          hunt through classes like Arrays and Doubles for them.
      - Supports a copy-free .subArray view, so methods that accept this type don't need to
          add overloads that accept start and end indexes.
      - Can be streamed without "breaking the chain": `foo.getBarDoubles().stream()...`.
      - Access to all collection-based utilities via .asList (though at the cost of
          allocating garbage).
    
    
    Disadvantages compared to `double[]`:
    
    
      - Memory footprint has a fixed overhead (about 24 bytes per instance).
      - *Some* construction use cases force the data to be copied (though several construction
          APIs are offered that don't).
      - Can't be passed directly to methods that expect `double[]` (though the most common
          utilities do have replacements here).
      - Dependency on `com.google.common` / Guava.
    
    
    Advantages compared to com.google.common.collect.ImmutableList ImmutableList`<Double>`:
    
    
      - Improved memory compactness and locality.
      - Can be queried without allocating garbage.
      - Access to `DoubleStream` features (like DoubleStream.sum) using `stream()` instead of the awkward `stream().mapToDouble(v -> v)`.
    
    
    Disadvantages compared to `ImmutableList<Double>`:
    
    
      - Can't be passed directly to methods that expect `Iterable`, `Collection`, or
          `List` (though the most common utilities do have replacements here, and there is a
          lazy .asList view).

    Since
    - 22.0
    """

    @staticmethod
    def of() -> "ImmutableDoubleArray":
        """
        Returns the empty array.
        """
        ...


    @staticmethod
    def of(e0: float) -> "ImmutableDoubleArray":
        """
        Returns an immutable array containing a single value.
        """
        ...


    @staticmethod
    def of(e0: float, e1: float) -> "ImmutableDoubleArray":
        """
        Returns an immutable array containing the given values, in order.
        """
        ...


    @staticmethod
    def of(e0: float, e1: float, e2: float) -> "ImmutableDoubleArray":
        """
        Returns an immutable array containing the given values, in order.
        """
        ...


    @staticmethod
    def of(e0: float, e1: float, e2: float, e3: float) -> "ImmutableDoubleArray":
        """
        Returns an immutable array containing the given values, in order.
        """
        ...


    @staticmethod
    def of(e0: float, e1: float, e2: float, e3: float, e4: float) -> "ImmutableDoubleArray":
        """
        Returns an immutable array containing the given values, in order.
        """
        ...


    @staticmethod
    def of(e0: float, e1: float, e2: float, e3: float, e4: float, e5: float) -> "ImmutableDoubleArray":
        """
        Returns an immutable array containing the given values, in order.
        """
        ...


    @staticmethod
    def of(first: float, *rest: Tuple[float, ...]) -> "ImmutableDoubleArray":
        ...


    @staticmethod
    def copyOf(values: list[float]) -> "ImmutableDoubleArray":
        """
        Returns an immutable array containing the given values, in order.
        """
        ...


    @staticmethod
    def copyOf(values: Iterable["Double"]) -> "ImmutableDoubleArray":
        """
        Returns an immutable array containing the given values, in order.
        """
        ...


    @staticmethod
    def copyOf(values: Iterable["Double"]) -> "ImmutableDoubleArray":
        """
        Returns an immutable array containing the given values, in order.
        
        **Performance note:** this method delegates to .copyOf(Collection) if `values` is a Collection. Otherwise it creates a .builder and uses Builder.addAll(Iterable), with all the performance implications associated with that.
        """
        ...


    @staticmethod
    def copyOf(stream: "DoubleStream") -> "ImmutableDoubleArray":
        """
        Returns an immutable array containing all the values from `stream`, in order.
        """
        ...


    @staticmethod
    def builder(initialCapacity: int) -> "Builder":
        """
        Returns a new, empty builder for ImmutableDoubleArray instances, sized to hold up to
        `initialCapacity` values without resizing. The returned builder is not thread-safe.
        
        **Performance note:** When feasible, `initialCapacity` should be the exact number
        of values that will be added, if that knowledge is readily available. It is better to guess a
        value slightly too high than slightly too low. If the value is not exact, the ImmutableDoubleArray that is built will very likely occupy more memory than strictly
        necessary; to trim memory usage, build using `builder.build().trimmed()`.
        """
        ...


    @staticmethod
    def builder() -> "Builder":
        """
        Returns a new, empty builder for ImmutableDoubleArray instances, with a default initial
        capacity. The returned builder is not thread-safe.
        
        **Performance note:** The ImmutableDoubleArray that is built will very likely
        occupy more memory than necessary; to trim memory usage, build using `builder.build().trimmed()`.
        """
        ...


    def length(self) -> int:
        """
        Returns the number of values in this array.
        """
        ...


    def isEmpty(self) -> bool:
        """
        Returns `True` if there are no values in this array (.length is zero).
        """
        ...


    def get(self, index: int) -> float:
        """
        Returns the `double` value present at the given index.

        Raises
        - IndexOutOfBoundsException: if `index` is negative, or greater than or equal to
            .length
        """
        ...


    def indexOf(self, target: float) -> int:
        """
        Returns the smallest index for which .get returns `target`, or `-1` if no
        such index exists. Values are compared as if by Double.equals. Equivalent to `asList().indexOf(target)`.
        """
        ...


    def lastIndexOf(self, target: float) -> int:
        """
        Returns the largest index for which .get returns `target`, or `-1` if no
        such index exists. Values are compared as if by Double.equals. Equivalent to `asList().lastIndexOf(target)`.
        """
        ...


    def contains(self, target: float) -> bool:
        """
        Returns `True` if `target` is present at any index in this array. Values are
        compared as if by Double.equals. Equivalent to `asList().contains(target)`.
        """
        ...


    def forEach(self, consumer: "DoubleConsumer") -> None:
        """
        Invokes `consumer` for each value contained in this array, in order.
        """
        ...


    def stream(self) -> "DoubleStream":
        """
        Returns a stream over the values in this array, in order.
        """
        ...


    def toArray(self) -> list[float]:
        """
        Returns a new, mutable copy of this array's values, as a primitive `double[]`.
        """
        ...


    def subArray(self, startIndex: int, endIndex: int) -> "ImmutableDoubleArray":
        """
        Returns a new immutable array containing the values in the specified range.
        
        **Performance note:** The returned array has the same full memory footprint as this one
        does (no actual copying is performed). To reduce memory usage, use `subArray(start,
        end).trimmed()`.
        """
        ...


    def asList(self) -> list["Double"]:
        """
        Returns an immutable *view* of this array's values as a `List`; note that `double` values are boxed into Double instances on demand, which can be very expensive.
        The returned list should be used once and discarded. For any usages beyond that, pass the
        returned list to com.google.common.collect.ImmutableList.copyOf(Collection)
        ImmutableList.copyOf and use that list instead.
        """
        ...


    def equals(self, object: "Object") -> bool:
        """
        Returns `True` if `object` is an `ImmutableDoubleArray` containing the same
        values as this one, in the same order. Values are compared as if by Double.equals.
        """
        ...


    def hashCode(self) -> int:
        """
        Returns an unspecified hash code for the contents of this immutable array.
        """
        ...


    def toString(self) -> str:
        """
        Returns a string representation of this array in the same form as Arrays.toString(double[]), for example `"[1, 2, 3]"`.
        """
        ...


    def trimmed(self) -> "ImmutableDoubleArray":
        """
        Returns an immutable array containing the same values as `this` array. This is logically
        a no-op, and in some circumstances `this` itself is returned. However, if this instance
        is a .subArray view of a larger array, this method will copy only the appropriate range
        of values, resulting in an equivalent array with a smaller memory footprint.
        """
        ...


    class Builder:
        """
        A builder for ImmutableDoubleArray instances; obtained using ImmutableDoubleArray.builder.
        """

        def add(self, value: float) -> "Builder":
            """
            Appends `value` to the end of the values the built ImmutableDoubleArray will
            contain.
            """
            ...


        def addAll(self, values: list[float]) -> "Builder":
            """
            Appends `values`, in order, to the end of the values the built ImmutableDoubleArray will contain.
            """
            ...


        def addAll(self, values: Iterable["Double"]) -> "Builder":
            """
            Appends `values`, in order, to the end of the values the built ImmutableDoubleArray will contain.
            """
            ...


        def addAll(self, values: Iterable["Double"]) -> "Builder":
            """
            Appends `values`, in order, to the end of the values the built ImmutableDoubleArray will contain.
            """
            ...


        def addAll(self, stream: "DoubleStream") -> "Builder":
            """
            Appends all values from `stream`, in order, to the end of the values the built ImmutableDoubleArray will contain.
            """
            ...


        def addAll(self, values: "ImmutableDoubleArray") -> "Builder":
            """
            Appends `values`, in order, to the end of the values the built ImmutableDoubleArray will contain.
            """
            ...


        def build(self) -> "ImmutableDoubleArray":
            """
            Returns a new immutable array. The builder can continue to be used after this call, to append
            more values and build again.
            
            **Performance note:** the returned array is backed by the same array as the builder, so
            no data is copied as part of this step, but this may occupy more memory than strictly
            necessary. To copy the data to a right-sized backing array, use `.build().trimmed()`.
            """
            ...



"""
Python module generated from Java source file com.google.gson.internal.Excluder

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import ExclusionStrategy
from com.google.gson import FieldAttributes
from com.google.gson import Gson
from com.google.gson import TypeAdapter
from com.google.gson import TypeAdapterFactory
from com.google.gson.annotations import Expose
from com.google.gson.annotations import Since
from com.google.gson.annotations import Until
from com.google.gson.internal import *
from com.google.gson.internal.reflect import ReflectionHelper
from com.google.gson.reflect import TypeToken
from com.google.gson.stream import JsonReader
from com.google.gson.stream import JsonWriter
from java.io import IOException
from java.lang.reflect import Field
from java.lang.reflect import Modifier
from java.util import Collections
from typing import Any, Callable, Iterable, Tuple


class Excluder(TypeAdapterFactory, Cloneable):
    """
    This class selects which fields and types to omit. It is configurable, supporting version
    attributes Since and Until, modifiers, synthetic fields, anonymous and local
    classes, inner classes, and fields with the Expose annotation.
    
    This class is a type adapter factory; types that are excluded will be adapted to null. It may
    delegate to another type adapter if only one direction is excluded.

    Author(s)
    - Jesse Wilson
    """

    DEFAULT = Excluder()


    def withVersion(self, ignoreVersionsAfter: float) -> "Excluder":
        ...


    def withModifiers(self, *modifiers: Tuple[int, ...]) -> "Excluder":
        ...


    def disableInnerClassSerialization(self) -> "Excluder":
        ...


    def excludeFieldsWithoutExposeAnnotation(self) -> "Excluder":
        ...


    def withExclusionStrategy(self, exclusionStrategy: "ExclusionStrategy", serialization: bool, deserialization: bool) -> "Excluder":
        ...


    def create(self, gson: "Gson", type: "TypeToken"["T"]) -> "TypeAdapter"["T"]:
        ...


    def excludeField(self, field: "Field", serialize: bool) -> bool:
        ...


    def excludeClass(self, clazz: type[Any], serialize: bool) -> bool:
        ...



"""
Python module generated from Java source file java.nio.charset.CharsetEncoder

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.lang.ref import WeakReference
from java.nio.charset import *
from java.nio.charset import CoderMalfunctionError
from java.util import Arrays
from typing import Any, Callable, Iterable, Tuple


class CharsetEncoder:

    def charset(self) -> "Charset":
        """
        Returns the charset that created this encoder.

        Returns
        - This encoder's charset
        """
        ...


    def replacement(self) -> list[int]:
        """
        Returns this encoder's replacement value.

        Returns
        - This encoder's current replacement,
                 which is never `null` and is never empty
        """
        ...


    def replaceWith(self, newReplacement: list[int]) -> "CharsetEncoder":
        """
        Changes this encoder's replacement value.
        
         This method invokes the .implReplaceWith implReplaceWith
        method, passing the new replacement, after checking that the new
        replacement is acceptable.  

        Arguments
        - newReplacement: The new replacement; must not be
                `null`, must have non-zero length,
        
        
        
        
        
                must not be longer than the value returned by the
                .maxBytesPerChar() maxBytesPerChar method, and
                must be .isLegalReplacement legal

        Returns
        - This encoder

        Raises
        - IllegalArgumentException: If the preconditions on the parameter do not hold
        """
        ...


    def isLegalReplacement(self, repl: list[int]) -> bool:
        """
        Tells whether or not the given byte array is a legal replacement value
        for this encoder.
        
         A replacement is legal if, and only if, it is a legal sequence of
        bytes in this encoder's charset; that is, it must be possible to decode
        the replacement into one or more sixteen-bit Unicode characters.
        
         The default implementation of this method is not very efficient; it
        should generally be overridden to improve performance.  

        Arguments
        - repl: The byte array to be tested

        Returns
        - `True` if, and only if, the given byte array
                 is a legal replacement value for this encoder
        """
        ...


    def malformedInputAction(self) -> "CodingErrorAction":
        """
        Returns this encoder's current action for malformed-input errors.

        Returns
        - The current malformed-input action, which is never `null`
        """
        ...


    def onMalformedInput(self, newAction: "CodingErrorAction") -> "CharsetEncoder":
        """
        Changes this encoder's action for malformed-input errors.
        
         This method invokes the .implOnMalformedInput
        implOnMalformedInput method, passing the new action.  

        Arguments
        - newAction: The new action; must not be `null`

        Returns
        - This encoder

        Raises
        - IllegalArgumentException: If the precondition on the parameter does not hold
        """
        ...


    def unmappableCharacterAction(self) -> "CodingErrorAction":
        """
        Returns this encoder's current action for unmappable-character errors.

        Returns
        - The current unmappable-character action, which is never
                `null`
        """
        ...


    def onUnmappableCharacter(self, newAction: "CodingErrorAction") -> "CharsetEncoder":
        """
        Changes this encoder's action for unmappable-character errors.
        
         This method invokes the .implOnUnmappableCharacter
        implOnUnmappableCharacter method, passing the new action.  

        Arguments
        - newAction: The new action; must not be `null`

        Returns
        - This encoder

        Raises
        - IllegalArgumentException: If the precondition on the parameter does not hold
        """
        ...


    def averageBytesPerChar(self) -> float:
        """
        Returns the average number of bytes that will be produced for each
        character of input.  This heuristic value may be used to estimate the size
        of the output buffer required for a given input sequence.

        Returns
        - The average number of bytes produced
                 per character of input
        """
        ...


    def maxBytesPerChar(self) -> float:
        """
        Returns the maximum number of bytes that will be produced for each
        character of input.  This value may be used to compute the worst-case size
        of the output buffer required for a given input sequence. This value
        accounts for any necessary content-independent prefix or suffix
        
        bytes, such as byte-order marks.

        Returns
        - The maximum number of bytes that will be produced per
                 character of input
        """
        ...


    def encode(self, in: "CharBuffer", out: "ByteBuffer", endOfInput: bool) -> "CoderResult":
        """
        Encodes as many characters as possible from the given input buffer,
        writing the results to the given output buffer.
        
         The buffers are read from, and written to, starting at their current
        positions.  At most Buffer.remaining in.remaining() characters
        will be read and at most Buffer.remaining out.remaining()
        bytes will be written.  The buffers' positions will be advanced to
        reflect the characters read and the bytes written, but their marks and
        limits will not be modified.
        
         In addition to reading characters from the input buffer and writing
        bytes to the output buffer, this method returns a CoderResult
        object to describe its reason for termination:
        
        
        
          -  CoderResult.UNDERFLOW indicates that as much of the
          input buffer as possible has been encoded.  If there is no further
          input then the invoker can proceed to the next step of the
          <a href="#steps">encoding operation</a>.  Otherwise this method
          should be invoked again with further input.  
        
          -  CoderResult.OVERFLOW indicates that there is
          insufficient space in the output buffer to encode any more characters.
          This method should be invoked again with an output buffer that has
          more Buffer.remaining remaining bytes. This is
          typically done by draining any encoded bytes from the output
          buffer.  
        
          -  A CoderResult.malformedForLength
          malformed-input result indicates that a malformed-input
          error has been detected.  The malformed characters begin at the input
          buffer's (possibly incremented) position; the number of malformed
          characters may be determined by invoking the result object's CoderResult.length() length method.  This case applies only if the
          .onMalformedInput malformed action of this encoder
          is CodingErrorAction.REPORT; otherwise the malformed input
          will be ignored or replaced, as requested.  
        
          -  An CoderResult.unmappableForLength
          unmappable-character result indicates that an
          unmappable-character error has been detected.  The characters that
          encode the unmappable character begin at the input buffer's (possibly
          incremented) position; the number of such characters may be determined
          by invoking the result object's CoderResult.length() length
          method.  This case applies only if the .onUnmappableCharacter
          unmappable action of this encoder is CodingErrorAction.REPORT; otherwise the unmappable character will be
          ignored or replaced, as requested.  
        
        
        
        In any case, if this method is to be reinvoked in the same encoding
        operation then care should be taken to preserve any characters remaining
        in the input buffer so that they are available to the next invocation.
        
         The `endOfInput` parameter advises this method as to whether
        the invoker can provide further input beyond that contained in the given
        input buffer.  If there is a possibility of providing additional input
        then the invoker should pass `False` for this parameter; if there
        is no possibility of providing further input then the invoker should
        pass `True`.  It is not erroneous, and in fact it is quite
        common, to pass `False` in one invocation and later discover that
        no further input was actually available.  It is critical, however, that
        the final invocation of this method in a sequence of invocations always
        pass `True` so that any remaining unencoded input will be treated
        as being malformed.
        
         This method works by invoking the .encodeLoop encodeLoop
        method, interpreting its results, handling error conditions, and
        reinvoking it as necessary.  

        Arguments
        - in: The input character buffer
        - out: The output byte buffer
        - endOfInput: `True` if, and only if, the invoker can provide no
                additional input characters beyond those in the given buffer

        Returns
        - A coder-result object describing the reason for termination

        Raises
        - IllegalStateException: If an encoding operation is already in progress and the previous
                 step was an invocation neither of the .reset reset
                 method, nor of this method with a value of `False` for
                 the `endOfInput` parameter, nor of this method with a
                 value of `True` for the `endOfInput` parameter
                 but a return value indicating an incomplete encoding operation
        - CoderMalfunctionError: If an invocation of the encodeLoop method threw
                 an unexpected exception
        """
        ...


    def flush(self, out: "ByteBuffer") -> "CoderResult":
        """
        Flushes this encoder.
        
         Some encoders maintain internal state and may need to write some
        final bytes to the output buffer once the overall input sequence has
        been read.
        
         Any additional output is written to the output buffer beginning at
        its current position.  At most Buffer.remaining out.remaining()
        bytes will be written.  The buffer's position will be advanced
        appropriately, but its mark and limit will not be modified.
        
         If this method completes successfully then it returns CoderResult.UNDERFLOW.  If there is insufficient room in the output
        buffer then it returns CoderResult.OVERFLOW.  If this happens
        then this method must be invoked again, with an output buffer that has
        more room, in order to complete the current <a href="#steps">encoding
        operation</a>.
        
         If this encoder has already been flushed then invoking this method
        has no effect.
        
         This method invokes the .implFlush implFlush method to
        perform the actual flushing operation.  

        Arguments
        - out: The output byte buffer

        Returns
        - A coder-result object, either CoderResult.UNDERFLOW or
                 CoderResult.OVERFLOW

        Raises
        - IllegalStateException: If the previous step of the current encoding operation was an
                 invocation neither of the .flush flush method nor of
                 the three-argument .encode(CharBuffer,ByteBuffer,boolean) encode method
                 with a value of `True` for the `endOfInput`
                 parameter
        """
        ...


    def reset(self) -> "CharsetEncoder":
        """
        Resets this encoder, clearing any internal state.
        
         This method resets charset-independent state and also invokes the
        .implReset() implReset method in order to perform any
        charset-specific reset actions.  

        Returns
        - This encoder
        """
        ...


    def encode(self, in: "CharBuffer") -> "ByteBuffer":
        """
        Convenience method that encodes the remaining content of a single input
        character buffer into a newly-allocated byte buffer.
        
         This method implements an entire <a href="#steps">encoding
        operation</a>; that is, it resets this encoder, then it encodes the
        characters in the given character buffer, and finally it flushes this
        encoder.  This method should therefore not be invoked if an encoding
        operation is already in progress.  

        Arguments
        - in: The input character buffer

        Returns
        - A newly-allocated byte buffer containing the result of the
                encoding operation.  The buffer's position will be zero and its
                limit will follow the last byte written.

        Raises
        - IllegalStateException: If an encoding operation is already in progress
        - MalformedInputException: If the character sequence starting at the input buffer's current
                 position is not a legal sixteen-bit Unicode sequence and the current malformed-input action
                 is CodingErrorAction.REPORT
        - UnmappableCharacterException: If the character sequence starting at the input buffer's current
                 position cannot be mapped to an equivalent byte sequence and
                 the current unmappable-character action is CodingErrorAction.REPORT
        """
        ...


    def canEncode(self, c: str) -> bool:
        """
        Tells whether or not this encoder can encode the given character.
        
         This method returns `False` if the given character is a
        surrogate character; such characters can be interpreted only when they
        are members of a pair consisting of a high surrogate followed by a low
        surrogate.  The .canEncode(java.lang.CharSequence)
        canEncode(CharSequence) method may be used to test whether or not a
        character sequence can be encoded.
        
         This method may modify this encoder's state; it should therefore not
        be invoked if an <a href="#steps">encoding operation</a> is already in
        progress.
        
         The default implementation of this method is not very efficient; it
        should generally be overridden to improve performance.  

        Arguments
        - c: The given character

        Returns
        - `True` if, and only if, this encoder can encode
                 the given character

        Raises
        - IllegalStateException: If an encoding operation is already in progress
        """
        ...


    def canEncode(self, cs: "CharSequence") -> bool:
        """
        Tells whether or not this encoder can encode the given character
        sequence.
        
         If this method returns `False` for a particular character
        sequence then more information about why the sequence cannot be encoded
        may be obtained by performing a full <a href="#steps">encoding
        operation</a>.
        
         This method may modify this encoder's state; it should therefore not
        be invoked if an encoding operation is already in progress.
        
         The default implementation of this method is not very efficient; it
        should generally be overridden to improve performance.  

        Arguments
        - cs: The given character sequence

        Returns
        - `True` if, and only if, this encoder can encode
                 the given character without throwing any exceptions and without
                 performing any replacements

        Raises
        - IllegalStateException: If an encoding operation is already in progress
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.TreeBasedTable

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.base import Supplier
from com.google.common.collect import *
from java.io import Serializable
from java.util import Comparator
from java.util import Iterator
from java.util import NoSuchElementException
from java.util import SortedMap
from java.util import SortedSet
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class TreeBasedTable(StandardRowSortedTable):
    """
    Implementation of `Table` whose row keys and column keys are ordered by their natural
    ordering or by supplied comparators. When constructing a `TreeBasedTable`, you may provide
    comparators for the row keys and the column keys, or you may use natural ordering for both.
    
    The .rowKeySet method returns a SortedSet and the .rowMap method
    returns a SortedMap, instead of the Set and Map specified by the Table interface.
    
    The views returned by .column, .columnKeySet(), and .columnMap() have
    iterators that don't support `remove()`. Otherwise, all optional operations are supported.
    Null row keys, columns keys, and values are not supported.
    
    Lookups by row key are often faster than lookups by column key, because the data is stored in
    a `Map<R, Map<C, V>>`. A method call like `column(columnKey).get(rowKey)` still runs
    quickly, since the row key is provided. However, `column(columnKey).size()` takes longer,
    since an iteration across all row keys occurs.
    
    Because a `TreeBasedTable` has unique sorted values for a given row, both `row(rowKey)` and `rowMap().get(rowKey)` are SortedMap instances, instead of the
    Map specified in the Table interface.
    
    Note that this implementation is not synchronized. If multiple threads access this table
    concurrently and one of the threads modifies the table, it must be synchronized externally.
    
    See the Guava User Guide article on <a href=
    "https://github.com/google/guava/wiki/NewCollectionTypesExplained#table">`Table`</a>.

    Author(s)
    - Louis Wasserman

    Since
    - 7.0
    """

    @staticmethod
    def create() -> "TreeBasedTable"["R", "C", "V"]:
        """
        Creates an empty `TreeBasedTable` that uses the natural orderings of both row and column
        keys.
        
        The method signature specifies `R extends Comparable` with a raw Comparable,
        instead of `R extends Comparable<? super R>`, and the same for `C`. That's
        necessary to support classes defined without generics.
        """
        ...


    @staticmethod
    def create(rowComparator: "Comparator"["R"], columnComparator: "Comparator"["C"]) -> "TreeBasedTable"["R", "C", "V"]:
        """
        Creates an empty `TreeBasedTable` that is ordered by the specified comparators.

        Arguments
        - rowComparator: the comparator that orders the row keys
        - columnComparator: the comparator that orders the column keys
        """
        ...


    @staticmethod
    def create(table: "TreeBasedTable"["R", "C", "V"]) -> "TreeBasedTable"["R", "C", "V"]:
        """
        Creates a `TreeBasedTable` with the same mappings and sort order as the specified `TreeBasedTable`.
        """
        ...


    def rowComparator(self) -> "Comparator"["R"]:
        """
        Returns the comparator that orders the rows. With natural ordering, Ordering.natural()
        is returned.

        Deprecated
        - Use `table.rowKeySet().comparator()` instead.
        """
        ...


    def columnComparator(self) -> "Comparator"["C"]:
        """
        Returns the comparator that orders the columns. With natural ordering, Ordering.natural() is returned.

        Deprecated
        - Store the Comparator alongside the Table. Or, if you know that the
            Table contains at least one value, you can retrieve the Comparator with:
            `((SortedMap<C, V>) table.rowMap().values().iterator().next()).comparator();`.
        """
        ...


    def row(self, rowKey: "R") -> "SortedMap"["C", "V"]:
        """
        
        
        Because a `TreeBasedTable` has unique sorted values for a given row, this method
        returns a SortedMap, instead of the Map specified in the Table
        interface.

        Since
        - 10.0 (<a href="https://github.com/google/guava/wiki/Compatibility" >mostly
            source-compatible</a> since 7.0)
        """
        ...


    def rowKeySet(self) -> "SortedSet"["R"]:
        ...


    def rowMap(self) -> "SortedMap"["R", dict["C", "V"]]:
        ...



from .SimpleCommandMap import SimpleCommandMap
from .PluginCommand import PluginCommand
from .ProxiedCommandSender import ProxiedCommandSender
from .RemoteConsoleCommandSender import RemoteConsoleCommandSender
from .Command import Command
from .ConsoleCommandSender import ConsoleCommandSender
from .CommandMap import CommandMap
from .CommandExecutor import CommandExecutor
from .CommandSender import CommandSender
from .MultipleCommandAlias import MultipleCommandAlias
from .BlockCommandSender import BlockCommandSender
from .TabExecutor import TabExecutor
from .FormattedCommandAlias import FormattedCommandAlias
from .CommandException import CommandException
from .PluginCommandYamlParser import PluginCommandYamlParser
from .TabCompleter import TabCompleter
from .PluginIdentifiableCommand import PluginIdentifiableCommand


"""
Python module generated from Java source file org.bukkit.entity.minecart.HopperMinecart

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Minecart
from org.bukkit.entity.minecart import *
from org.bukkit.inventory import InventoryHolder
from org.bukkit.loot import Lootable
from typing import Any, Callable, Iterable, Tuple


class HopperMinecart(Minecart, InventoryHolder, Lootable):
    """
    Represents a Minecart with a Hopper inside it
    """

    def isEnabled(self) -> bool:
        """
        Checks whether or not this Minecart will pick up
        items into its inventory.

        Returns
        - True if the Minecart will pick up items
        """
        ...


    def setEnabled(self, enabled: bool) -> None:
        """
        Sets whether this Minecart will pick up items.

        Arguments
        - enabled: new enabled state
        """
        ...



"""
Python module generated from Java source file org.bukkit.block.ChiseledBookshelf

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import *
from org.bukkit.inventory import BlockInventoryHolder
from org.bukkit.inventory import ChiseledBookshelfInventory
from org.bukkit.util import Vector
from typing import Any, Callable, Iterable, Tuple


class ChiseledBookshelf(TileState, BlockInventoryHolder):
    """
    Represents a captured state of a chiseled bookshelf.
    """

    def getLastInteractedSlot(self) -> int:
        """
        Gets the last interacted inventory slot.

        Returns
        - the last interacted slot
        """
        ...


    def setLastInteractedSlot(self, lastInteractedSlot: int) -> None:
        """
        Sets the last interacted inventory slot.

        Arguments
        - lastInteractedSlot: the new last interacted slot
        """
        ...


    def getInventory(self) -> "ChiseledBookshelfInventory":
        """
        Returns
        - inventory

        See
        - Container.getInventory()
        """
        ...


    def getSnapshotInventory(self) -> "ChiseledBookshelfInventory":
        """
        Returns
        - snapshot inventory

        See
        - Container.getSnapshotInventory()
        """
        ...


    def getSlot(self, position: "Vector") -> int:
        """
        Gets the appropriate slot based on a vector relative to this block.
        Will return -1 if the given vector is not within the bounds of any slot.
        
        The supplied vector should only contain components with values between 0.0
        and 1.0, inclusive.

        Arguments
        - position: a vector relative to this block

        Returns
        - the slot under the given vector or -1
        """
        ...



"""
Python module generated from Java source file java.util.Queue

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import *
from typing import Any, Callable, Iterable, Tuple


class Queue(Collection):
    """
    A collection designed for holding elements prior to processing.
    Besides basic Collection operations, queues provide
    additional insertion, extraction, and inspection operations.
    Each of these methods exists in two forms: one throws an exception
    if the operation fails, the other returns a special value (either
    `null` or `False`, depending on the operation).  The
    latter form of the insert operation is designed specifically for
    use with capacity-restricted `Queue` implementations; in most
    implementations, insert operations cannot fail.
    
    <table class="striped">
    <caption>Summary of Queue methods</caption>
     <thead>
     <tr>
       <td></td>
       <th scope="col" style="font-weight:normal; font-style:italic">Throws exception</th>
       <th scope="col" style="font-weight:normal; font-style:italic">Returns special value</th>
     </tr>
     </thead>
     <tbody>
     <tr>
       <th scope="row">Insert</th>
       <td>.add(Object) add(e)</td>
       <td>.offer(Object) offer(e)</td>
     </tr>
     <tr>
       <th scope="row">Remove</th>
       <td>.remove() remove()</td>
       <td>.poll() poll()</td>
     </tr>
     <tr>
       <th scope="row">Examine</th>
       <td>.element() element()</td>
       <td>.peek() peek()</td>
     </tr>
     </tbody>
    </table>
    
    Queues typically, but do not necessarily, order elements in a
    FIFO (first-in-first-out) manner.  Among the exceptions are
    priority queues, which order elements according to a supplied
    comparator, or the elements' natural ordering, and LIFO queues (or
    stacks) which order the elements LIFO (last-in-first-out).
    Whatever the ordering used, the *head* of the queue is that
    element which would be removed by a call to .remove() or
    .poll().  In a FIFO queue, all new elements are inserted at
    the *tail* of the queue. Other kinds of queues may use
    different placement rules.  Every `Queue` implementation
    must specify its ordering properties.
    
    The .offer offer method inserts an element if possible,
    otherwise returning `False`.  This differs from the java.util.Collection.add Collection.add method, which can fail to
    add an element only by throwing an unchecked exception.  The
    `offer` method is designed for use when failure is a normal,
    rather than exceptional occurrence, for example, in fixed-capacity
    (or &quot;bounded&quot;) queues.
    
    The .remove() and .poll() methods remove and
    return the head of the queue.
    Exactly which element is removed from the queue is a
    function of the queue's ordering policy, which differs from
    implementation to implementation. The `remove()` and
    `poll()` methods differ only in their behavior when the
    queue is empty: the `remove()` method throws an exception,
    while the `poll()` method returns `null`.
    
    The .element() and .peek() methods return, but do
    not remove, the head of the queue.
    
    The `Queue` interface does not define the *blocking queue
    methods*, which are common in concurrent programming.  These methods,
    which wait for elements to appear or for space to become available, are
    defined in the java.util.concurrent.BlockingQueue interface, which
    extends this interface.
    
    `Queue` implementations generally do not allow insertion
    of `null` elements, although some implementations, such as
    LinkedList, do not prohibit insertion of `null`.
    Even in the implementations that permit it, `null` should
    not be inserted into a `Queue`, as `null` is also
    used as a special return value by the `poll` method to
    indicate that the queue contains no elements.
    
    `Queue` implementations generally do not define
    element-based versions of methods `equals` and
    `hashCode` but instead inherit the identity based versions
    from class `Object`, because element-based equality is not
    always well-defined for queues with the same elements but different
    ordering properties.
    
    This interface is a member of the
    <a href="/java.base/java/util/package-summary.html#CollectionsFramework">
    Java Collections Framework</a>.
    
    Type `<E>`: the type of elements held in this queue

    Author(s)
    - Doug Lea

    Since
    - 1.5
    """

    def add(self, e: "E") -> bool:
        """
        Inserts the specified element into this queue if it is possible to do so
        immediately without violating capacity restrictions, returning
        `True` upon success and throwing an `IllegalStateException`
        if no space is currently available.

        Arguments
        - e: the element to add

        Returns
        - `True` (as specified by Collection.add)

        Raises
        - IllegalStateException: if the element cannot be added at this
                time due to capacity restrictions
        - ClassCastException: if the class of the specified element
                prevents it from being added to this queue
        - NullPointerException: if the specified element is null and
                this queue does not permit null elements
        - IllegalArgumentException: if some property of this element
                prevents it from being added to this queue
        """
        ...


    def offer(self, e: "E") -> bool:
        """
        Inserts the specified element into this queue if it is possible to do
        so immediately without violating capacity restrictions.
        When using a capacity-restricted queue, this method is generally
        preferable to .add, which can fail to insert an element only
        by throwing an exception.

        Arguments
        - e: the element to add

        Returns
        - `True` if the element was added to this queue, else
                `False`

        Raises
        - ClassCastException: if the class of the specified element
                prevents it from being added to this queue
        - NullPointerException: if the specified element is null and
                this queue does not permit null elements
        - IllegalArgumentException: if some property of this element
                prevents it from being added to this queue
        """
        ...


    def remove(self) -> "E":
        """
        Retrieves and removes the head of this queue.  This method differs
        from .poll() poll() only in that it throws an exception if
        this queue is empty.

        Returns
        - the head of this queue

        Raises
        - NoSuchElementException: if this queue is empty
        """
        ...


    def poll(self) -> "E":
        """
        Retrieves and removes the head of this queue,
        or returns `null` if this queue is empty.

        Returns
        - the head of this queue, or `null` if this queue is empty
        """
        ...


    def element(self) -> "E":
        """
        Retrieves, but does not remove, the head of this queue.  This method
        differs from .peek peek only in that it throws an exception
        if this queue is empty.

        Returns
        - the head of this queue

        Raises
        - NoSuchElementException: if this queue is empty
        """
        ...


    def peek(self) -> "E":
        """
        Retrieves, but does not remove, the head of this queue,
        or returns `null` if this queue is empty.

        Returns
        - the head of this queue, or `null` if this queue is empty
        """
        ...



"""
Python module generated from Java source file org.bukkit.entity.ShulkerBullet

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class ShulkerBullet(Projectile):

    def getTarget(self) -> "Entity":
        """
        Retrieve the target of this bullet.

        Returns
        - the targeted entity
        """
        ...


    def setTarget(self, target: "Entity") -> None:
        """
        Sets the target of this bullet

        Arguments
        - target: the entity to target
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.player.PlayerBucketEmptyEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Material
from org.bukkit.block import Block
from org.bukkit.block import BlockFace
from org.bukkit.entity import Player
from org.bukkit.event import HandlerList
from org.bukkit.event.player import *
from org.bukkit.inventory import EquipmentSlot
from org.bukkit.inventory import ItemStack
from typing import Any, Callable, Iterable, Tuple


class PlayerBucketEmptyEvent(PlayerBucketEvent):
    """
    Called when a player empties a bucket
    """

    def __init__(self, who: "Player", blockClicked: "Block", blockFace: "BlockFace", bucket: "Material", itemInHand: "ItemStack"):
        ...


    def __init__(self, who: "Player", block: "Block", blockClicked: "Block", blockFace: "BlockFace", bucket: "Material", itemInHand: "ItemStack"):
        ...


    def __init__(self, who: "Player", block: "Block", blockClicked: "Block", blockFace: "BlockFace", bucket: "Material", itemInHand: "ItemStack", hand: "EquipmentSlot"):
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file com.google.common.util.concurrent.ForwardingLock

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import J2ktIncompatible
from com.google.common.util.concurrent import *
from java.util.concurrent import TimeUnit
from java.util.concurrent.locks import Condition
from java.util.concurrent.locks import Lock
from typing import Any, Callable, Iterable, Tuple


class ForwardingLock(Lock):
    """
    Forwarding wrapper around a `Lock`.
    """

    def lock(self) -> None:
        ...


    def lockInterruptibly(self) -> None:
        ...


    def tryLock(self) -> bool:
        ...


    def tryLock(self, time: int, unit: "TimeUnit") -> bool:
        ...


    def unlock(self) -> None:
        ...


    def newCondition(self) -> "Condition":
        ...



"""
Python module generated from Java source file org.bukkit.util.VoxelShape

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.util import *
from typing import Any, Callable, Iterable, Tuple


class VoxelShape:
    """
    A shape made out of voxels.
    
    For example, used to represent the detailed collision shape of blocks.
    """

    def getBoundingBoxes(self) -> Iterable["BoundingBox"]:
        """
        Converts this shape into a collection of BoundingBox equivalent
        to the shape: a bounding box intersects with this block shape if it
        intersects with any of the shape's bounding boxes.

        Returns
        - shape converted to bounding boxes
        """
        ...


    def overlaps(self, other: "BoundingBox") -> bool:
        """
        Checks if the given bounding box intersects this block shape.

        Arguments
        - other: bounding box to test

        Returns
        - True if other overlaps this, False otherwise
        """
        ...



"""
Python module generated from Java source file com.google.gson.internal.bind.CollectionTypeAdapterFactory

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import Gson
from com.google.gson import TypeAdapter
from com.google.gson import TypeAdapterFactory
from com.google.gson.internal import $Gson$Types
from com.google.gson.internal import ConstructorConstructor
from com.google.gson.internal import ObjectConstructor
from com.google.gson.internal.bind import *
from com.google.gson.reflect import TypeToken
from com.google.gson.stream import JsonReader
from com.google.gson.stream import JsonToken
from com.google.gson.stream import JsonWriter
from java.io import IOException
from java.lang.reflect import Type
from typing import Any, Callable, Iterable, Tuple


class CollectionTypeAdapterFactory(TypeAdapterFactory):
    """
    Adapt a homogeneous collection of objects.
    """

    def __init__(self, constructorConstructor: "ConstructorConstructor"):
        ...


    def create(self, gson: "Gson", typeToken: "TypeToken"["T"]) -> "TypeAdapter"["T"]:
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.inspector.UnTrustedTagInspector

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml.inspector import *
from org.yaml.snakeyaml.nodes import Tag
from typing import Any, Callable, Iterable, Tuple


class UnTrustedTagInspector(TagInspector):
    """
    TagInspector which does not allow to create any custom instance. It should not be used when the
    data comes from untrusted source to prevent possible remote code invocation.
    """

    def isGlobalTagAllowed(self, tag: "Tag") -> bool:
        """
        Allow none

        Arguments
        - tag: - the global tag to reject

        Returns
        - always return False
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.ImmutableCollection

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.collect import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.errorprone.annotations import DoNotCall
from com.google.errorprone.annotations import DoNotMock
from java.io import InvalidObjectException
from java.io import ObjectInputStream
from java.io import Serializable
from java.util import AbstractCollection
from java.util import Collections
from java.util import Iterator
from java.util import Spliterator
from java.util.function import Predicate
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class ImmutableCollection(AbstractCollection, Serializable):
    """
    A Collection whose contents will never change, and which offers a few additional
    guarantees detailed below.
    
    **Warning:** avoid *direct* usage of ImmutableCollection as a type (just as
    with Collection itself). Prefer subtypes such as ImmutableSet or ImmutableList, which have well-defined .equals semantics, thus avoiding a common source
    of bugs and confusion.
    
    <h3>About *all* `Immutable-` collections</h3>
    
    The remainder of this documentation applies to every public `Immutable-` type in this
    package, whether it is a subtype of `ImmutableCollection` or not.
    
    <h4>Guarantees</h4>
    
    Each makes the following guarantees:
    
    
      - **Shallow immutability.** Elements can never be added, removed or replaced in this
          collection. This is a stronger guarantee than that of Collections.unmodifiableCollection, whose contents change whenever the wrapped collection
          is modified.
      - **Null-hostility.** This collection will never contain a null element.
      - **Deterministic iteration.** The iteration order is always well-defined, depending on
          how the collection was created. Typically this is insertion order unless an explicit
          ordering is otherwise specified (e.g. ImmutableSortedSet.naturalOrder). See the
          appropriate factory method for details. View collections such as ImmutableMultiset.elementSet iterate in the same order as the parent, except as noted.
      - **Thread safety.** It is safe to access this collection concurrently from multiple
          threads.
      - **Integrity.** This type cannot be subclassed outside this package (which would allow
          these guarantees to be violated).
    
    
    <h4>"Interfaces", not implementations</h4>
    
    These are classes instead of interfaces to prevent external subtyping, but should be thought
    of as interfaces in every important sense. Each public class such as ImmutableSet is a
    *type* offering meaningful behavioral guarantees. This is substantially different from the
    case of (say) HashSet, which is an *implementation*, with semantics that were
    largely defined by its supertype.
    
    For field types and method return types, you should generally use the immutable type (such as
    ImmutableList) instead of the general collection interface type (such as List).
    This communicates to your callers all of the semantic guarantees listed above, which is almost
    always very useful information.
    
    On the other hand, a *parameter* type of ImmutableList is generally a nuisance to
    callers. Instead, accept Iterable and have your method or constructor body pass it to the
    appropriate `copyOf` method itself.
    
    Expressing the immutability guarantee directly in the type that user code references is a
    powerful advantage. Although Java offers certain immutable collection factory methods, such as
    Collections.singleton(Object) and <a
    href="https://docs.oracle.com/javase/9/docs/api/java/util/Set.html#immutable">`Set.of`</a>,
    we recommend using *these* classes instead for this reason (as well as for consistency).
    
    <h4>Creation</h4>
    
    Except for logically "abstract" types like `ImmutableCollection` itself, each `Immutable` type provides the static operations you need to obtain instances of that type. These
    usually include:
    
    
      - Static methods named `of`, accepting an explicit list of elements or entries.
      - Static methods named `copyOf` (or `copyOfSorted`), accepting an existing
          collection whose contents should be copied.
      - A static nested `Builder` class which can be used to populate a new immutable
          instance.
    
    
    <h4>Warnings</h4>
    
    
      - **Warning:** as with any collection, it is almost always a bad idea to modify an element
          (in a way that affects its Object.equals behavior) while it is contained in a
          collection. Undefined behavior and bugs will result. It's generally best to avoid using
          mutable objects as elements at all, as many users may expect your "immutable" object to be
          *deeply* immutable.
    
    
    <h4>Performance notes</h4>
    
    
      - Implementations can be generally assumed to prioritize memory efficiency, then speed of
          access, and lastly speed of creation.
      - The `copyOf` methods will sometimes recognize that the actual copy operation is
          unnecessary; for example, `copyOf(copyOf(anArrayList))` should copy the data only
          once. This reduces the expense of habitually making defensive copies at API boundaries.
          However, the precise conditions for skipping the copy operation are undefined.
      - **Warning:** a view collection such as ImmutableMap.keySet or ImmutableList.subList may retain a reference to the entire data set, preventing it from
          being garbage collected. If some of the data is no longer reachable through other means,
          this constitutes a memory leak. Pass the view collection to the appropriate `copyOf`
          method to obtain a correctly-sized copy.
      - The performance of using the associated `Builder` class can be assumed to be no
          worse, and possibly better, than creating a mutable collection and copying it.
      - Implementations generally do not cache hash codes. If your element or key type has a slow
          `hashCode` implementation, it should cache it itself.
    
    
    <h4>Example usage</h4>
    
    ````class Foo {
      private static final ImmutableSet<String> RESERVED_CODES =
          ImmutableSet.of("AZ", "CQ", "ZX");
    
      private final ImmutableSet<String> codes;
    
      public Foo(Iterable<String> codes) {
        this.codes = ImmutableSet.copyOf(codes);
        checkArgument(Collections.disjoint(this.codes, RESERVED_CODES));`
    }
    }```
    
    <h3>See also</h3>
    
    See the Guava User Guide article on <a href=
    "https://github.com/google/guava/wiki/ImmutableCollectionsExplained">immutable collections</a>.

    Since
    - 2.0
    """

    def iterator(self) -> "UnmodifiableIterator"["E"]:
        """
        Returns an unmodifiable iterator across the elements in this collection.
        """
        ...


    def spliterator(self) -> "Spliterator"["E"]:
        ...


    def toArray(self) -> list["Object"]:
        ...


    def toArray(self, other: list["T"]) -> list["T"]:
        ...


    def contains(self, object: "Object") -> bool:
        ...


    def add(self, e: "E") -> bool:
        """
        Guaranteed to throw an exception and leave the collection unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def remove(self, object: "Object") -> bool:
        """
        Guaranteed to throw an exception and leave the collection unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def addAll(self, newElements: Iterable["E"]) -> bool:
        """
        Guaranteed to throw an exception and leave the collection unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def removeAll(self, oldElements: Iterable[Any]) -> bool:
        """
        Guaranteed to throw an exception and leave the collection unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def removeIf(self, filter: "Predicate"["E"]) -> bool:
        """
        Guaranteed to throw an exception and leave the collection unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def retainAll(self, elementsToKeep: Iterable[Any]) -> bool:
        """
        Guaranteed to throw an exception and leave the collection unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def clear(self) -> None:
        """
        Guaranteed to throw an exception and leave the collection unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def asList(self) -> "ImmutableList"["E"]:
        """
        Returns an `ImmutableList` containing the same elements, in the same order, as this
        collection.
        
        **Performance note:** in most cases this method can return quickly without actually
        copying anything. The exact circumstances under which the copy is performed are undefined and
        subject to change.

        Since
        - 2.0
        """
        ...


    class Builder:
        """
        Abstract base class for builders of ImmutableCollection types.

        Since
        - 10.0
        """

        def add(self, element: "E") -> "Builder"["E"]:
            """
            Adds `element` to the `ImmutableCollection` being built.
            
            Note that each builder class covariantly returns its own type from this method.

            Arguments
            - element: the element to add

            Returns
            - this `Builder` instance

            Raises
            - NullPointerException: if `element` is null
            """
            ...


        def add(self, *elements: Tuple["E", ...]) -> "Builder"["E"]:
            """
            Adds each element of `elements` to the `ImmutableCollection` being built.
            
            Note that each builder class overrides this method in order to covariantly return its own
            type.

            Arguments
            - elements: the elements to add

            Returns
            - this `Builder` instance

            Raises
            - NullPointerException: if `elements` is null or contains a null element
            """
            ...


        def addAll(self, elements: Iterable["E"]) -> "Builder"["E"]:
            """
            Adds each element of `elements` to the `ImmutableCollection` being built.
            
            Note that each builder class overrides this method in order to covariantly return its own
            type.

            Arguments
            - elements: the elements to add

            Returns
            - this `Builder` instance

            Raises
            - NullPointerException: if `elements` is null or contains a null element
            """
            ...


        def addAll(self, elements: Iterator["E"]) -> "Builder"["E"]:
            """
            Adds each element of `elements` to the `ImmutableCollection` being built.
            
            Note that each builder class overrides this method in order to covariantly return its own
            type.

            Arguments
            - elements: the elements to add

            Returns
            - this `Builder` instance

            Raises
            - NullPointerException: if `elements` is null or contains a null element
            """
            ...


        def build(self) -> "ImmutableCollection"["E"]:
            """
            Returns a newly-created `ImmutableCollection` of the appropriate type, containing the
            elements provided to this builder.
            
            Note that each builder class covariantly returns the appropriate type of `ImmutableCollection` from this method.
            """
            ...



"""
Python module generated from Java source file java.lang.reflect.ParameterizedType

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.lang.reflect import *
from typing import Any, Callable, Iterable, Tuple


class ParameterizedType(Type):
    """
    ParameterizedType represents a parameterized type such as
    `Collection<String>`.
    
    A parameterized type is created the first time it is needed by a
    reflective method, as specified in this package. When a
    parameterized type p is created, the generic class or interface declaration
    that p instantiates is resolved, and all type arguments of p are created
    recursively. See java.lang.reflect.TypeVariable
    TypeVariable for details on the creation process for type
    variables. Repeated creation of a parameterized type has no effect.
    
    Instances of classes that implement this interface must implement
    an equals() method that equates any two instances that share the
    same generic class or interface declaration and have equal type parameters.

    Since
    - 1.5

    Unknown Tags
    - 4.5 Parameterized Types
    """

    def getActualTypeArguments(self) -> list["Type"]:
        """
        Returns an array of `Type` objects representing the actual type
        arguments to this type.
        
        Note that in some cases, the returned array be empty. This can occur
        if this type represents a non-parameterized type nested within
        a parameterized type.

        Returns
        - an array of `Type` objects representing the actual type
            arguments to this type

        Raises
        - TypeNotPresentException: if any of the actual type arguments
            refers to a non-existent class or interface declaration
        - MalformedParameterizedTypeException: if any of the
            actual type parameters refer to a parameterized type that cannot
            be instantiated for any reason

        Since
        - 1.5
        """
        ...


    def getRawType(self) -> "Type":
        """
        Returns the `Type` object representing the class or interface
        that declared this type.

        Returns
        - the `Type` object representing the class or interface
            that declared this type

        Since
        - 1.5
        """
        ...


    def getOwnerType(self) -> "Type":
        """
        Returns a `Type` object representing the type that this type
        is a member of.  For example, if this type is `O<T>.I<S>`,
        return a representation of `O<T>`.
        
        If this type is a top-level type, `null` is returned.

        Returns
        - a `Type` object representing the type that
            this type is a member of. If this type is a top-level type,
            `null` is returned

        Raises
        - TypeNotPresentException: if the owner type
            refers to a non-existent class or interface declaration
        - MalformedParameterizedTypeException: if the owner type
            refers to a parameterized type that cannot be instantiated
            for any reason

        Since
        - 1.5
        """
        ...



"""
Python module generated from Java source file com.google.common.util.concurrent.TimeoutFuture

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.base import Preconditions
from com.google.common.util.concurrent import *
from com.google.errorprone.annotations.concurrent import LazyInit
from java.util.concurrent import ExecutionException
from java.util.concurrent import Future
from java.util.concurrent import ScheduledExecutorService
from java.util.concurrent import ScheduledFuture
from java.util.concurrent import TimeUnit
from java.util.concurrent import TimeoutException
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class TimeoutFuture(TrustedFuture):
    """
    Implementation of `Futures.withTimeout`.
    
    Future that delegates to another but will finish early (via a TimeoutException wrapped
    in an ExecutionException) if the specified duration expires. The delegate future is
    interrupted and cancelled if it times out.
    """





"""
Python module generated from Java source file com.google.common.collect.MinMaxPriorityQueue

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.annotations import VisibleForTesting
from com.google.common.collect import *
from com.google.common.math import IntMath
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.j2objc.annotations import Weak
from com.google.j2objc.annotations import WeakOuter
from java.util import AbstractQueue
from java.util import ArrayDeque
from java.util import Collections
from java.util import Comparator
from java.util import ConcurrentModificationException
from java.util import Iterator
from java.util import NoSuchElementException
from java.util import PriorityQueue
from java.util import Queue
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class MinMaxPriorityQueue(AbstractQueue):
    """
    A double-ended priority queue, which provides constant-time access to both its least element and
    its greatest element, as determined by the queue's specified comparator. If no comparator is
    given at creation time, the natural order of elements is used. If no maximum size is given at
    creation time, the queue is unbounded.
    
    Usage example:
    
    ````MinMaxPriorityQueue<User> users = MinMaxPriorityQueue.orderedBy(userComparator)
        .maximumSize(1000)
        .create();````
    
    As a Queue it functions exactly as a PriorityQueue: its head element -- the
    implicit target of the methods .peek(), .poll() and .remove() -- is
    defined as the *least* element in the queue according to the queue's comparator. But unlike
    a regular priority queue, the methods .peekLast, .pollLast and .removeLast are also provided, to act on the *greatest* element in the queue instead.
    
    A min-max priority queue can be configured with a maximum size. If so, each time the size of
    the queue exceeds that value, the queue automatically removes its greatest element according to
    its comparator (which might be the element that was just added). This is different from
    conventional bounded queues, which either block or reject new elements when full.
    
    This implementation is based on the <a
    href="http://portal.acm.org/citation.cfm?id=6621">min-max heap</a> developed by Atkinson, et al.
    Unlike many other double-ended priority queues, it stores elements in a single array, as compact
    as the traditional heap data structure used in PriorityQueue.
    
    This class is not thread-safe, and does not accept null elements.
    
    *Performance notes:*
    
    
      - If you only access one end of the queue, and do use a maximum size, this class will perform
          significantly worse than a `PriorityQueue` with manual eviction above the maximum
          size. In many cases Ordering.leastOf may work for your use case with significantly
          improved (and asymptotically superior) performance.
      - The retrieval operations .peek, .peekFirst, .peekLast, .element, and .size are constant-time.
      - The enqueuing and dequeuing operations (.offer, .add, and all the forms of
          .poll and .remove()) run in `O(log n) time`.
      - The .remove(Object) and .contains operations require linear (`O(n)`)
          time.
      - If you only access one end of the queue, and don't use a maximum size, this class is
          functionally equivalent to PriorityQueue, but significantly slower.

    Author(s)
    - Torbjorn Gannholm

    Since
    - 8.0
    """

    @staticmethod
    def create() -> "MinMaxPriorityQueue"["E"]:
        """
        Creates a new min-max priority queue with default settings: natural order, no maximum size, no
        initial contents, and an initial expected size of 11.
        """
        ...


    @staticmethod
    def create(initialContents: Iterable["E"]) -> "MinMaxPriorityQueue"["E"]:
        """
        Creates a new min-max priority queue using natural order, no maximum size, and initially
        containing the given elements.
        """
        ...


    @staticmethod
    def orderedBy(comparator: "Comparator"["B"]) -> "Builder"["B"]:
        ...


    @staticmethod
    def expectedSize(expectedSize: int) -> "Builder"["Comparable"]:
        """
        Creates and returns a new builder, configured to build `MinMaxPriorityQueue` instances
        sized appropriately to hold `expectedSize` elements.
        """
        ...


    @staticmethod
    def maximumSize(maximumSize: int) -> "Builder"["Comparable"]:
        """
        Creates and returns a new builder, configured to build `MinMaxPriorityQueue` instances
        that are limited to `maximumSize` elements. Each time a queue grows beyond this bound, it
        immediately removes its greatest element (according to its comparator), which might be the
        element that was just added.
        """
        ...


    def size(self) -> int:
        ...


    def add(self, element: "E") -> bool:
        """
        Adds the given element to this queue. If this queue has a maximum size, after adding `element` the queue will automatically evict its greatest element (according to its comparator),
        which may be `element` itself.

        Returns
        - `True` always
        """
        ...


    def addAll(self, newElements: Iterable["E"]) -> bool:
        ...


    def offer(self, element: "E") -> bool:
        """
        Adds the given element to this queue. If this queue has a maximum size, after adding `element` the queue will automatically evict its greatest element (according to its comparator),
        which may be `element` itself.
        """
        ...


    def poll(self) -> "E":
        ...


    def peek(self) -> "E":
        ...


    def pollFirst(self) -> "E":
        """
        Removes and returns the least element of this queue, or returns `null` if the queue is
        empty.
        """
        ...


    def removeFirst(self) -> "E":
        """
        Removes and returns the least element of this queue.

        Raises
        - NoSuchElementException: if the queue is empty
        """
        ...


    def peekFirst(self) -> "E":
        """
        Retrieves, but does not remove, the least element of this queue, or returns `null` if the
        queue is empty.
        """
        ...


    def pollLast(self) -> "E":
        """
        Removes and returns the greatest element of this queue, or returns `null` if the queue is
        empty.
        """
        ...


    def removeLast(self) -> "E":
        """
        Removes and returns the greatest element of this queue.

        Raises
        - NoSuchElementException: if the queue is empty
        """
        ...


    def peekLast(self) -> "E":
        """
        Retrieves, but does not remove, the greatest element of this queue, or returns `null` if
        the queue is empty.
        """
        ...


    def iterator(self) -> Iterator["E"]:
        """
        Returns an iterator over the elements contained in this collection, *in no particular
        order*.
        
        The iterator is *fail-fast*: If the MinMaxPriorityQueue is modified at any time after
        the iterator is created, in any way except through the iterator's own remove method, the
        iterator will generally throw a ConcurrentModificationException. Thus, in the face of
        concurrent modification, the iterator fails quickly and cleanly, rather than risking arbitrary,
        non-deterministic behavior at an undetermined time in the future.
        
        Note that the fail-fast behavior of an iterator cannot be guaranteed as it is, generally
        speaking, impossible to make any hard guarantees in the presence of unsynchronized concurrent
        modification. Fail-fast iterators throw `ConcurrentModificationException` on a
        best-effort basis. Therefore, it would be wrong to write a program that depended on this
        exception for its correctness: *the fail-fast behavior of iterators should be used only to
        detect bugs.*

        Returns
        - an iterator over the elements contained in this collection
        """
        ...


    def clear(self) -> None:
        ...


    def toArray(self) -> list["Object"]:
        ...


    def comparator(self) -> "Comparator"["E"]:
        """
        Returns the comparator used to order the elements in this queue. Obeys the general contract of
        PriorityQueue.comparator, but returns Ordering.natural instead of `null`
        to indicate natural ordering.
        """
        ...


    class Builder:
        """
        The builder class used in creation of min-max priority queues. Instead of constructing one
        directly, use MinMaxPriorityQueue.orderedBy(Comparator), MinMaxPriorityQueue.expectedSize(int) or MinMaxPriorityQueue.maximumSize(int).
        
        Type `<B>`: the upper bound on the eventual type that can be produced by this builder (for
            example, a `Builder<Number>` can produce a `Queue<Number>` or `Queue<Integer>` but not a `Queue<Object>`).

        Since
        - 8.0
        """

        def expectedSize(self, expectedSize: int) -> "Builder"["B"]:
            """
            Configures this builder to build min-max priority queues with an initial expected size of
            `expectedSize`.
            """
            ...


        def maximumSize(self, maximumSize: int) -> "Builder"["B"]:
            """
            Configures this builder to build `MinMaxPriorityQueue` instances that are limited to
            `maximumSize` elements. Each time a queue grows beyond this bound, it immediately
            removes its greatest element (according to its comparator), which might be the element that
            was just added.
            """
            ...


        def create(self) -> "MinMaxPriorityQueue"["T"]:
            """
            Builds a new min-max priority queue using the previously specified options, and having no
            initial contents.
            """
            ...


        def create(self, initialContents: Iterable["T"]) -> "MinMaxPriorityQueue"["T"]:
            """
            Builds a new min-max priority queue using the previously specified options, and having the
            given initial elements.
            """
            ...



"""
Python module generated from Java source file org.bukkit.event.player.PlayerAdvancementDoneEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.advancement import Advancement
from org.bukkit.entity import Player
from org.bukkit.event import HandlerList
from org.bukkit.event.player import *
from typing import Any, Callable, Iterable, Tuple


class PlayerAdvancementDoneEvent(PlayerEvent):
    """
    Called when a player has completed all criteria in an advancement.
    """

    def __init__(self, who: "Player", advancement: "Advancement"):
        ...


    def getAdvancement(self) -> "Advancement":
        """
        Get the advancement which has been completed.

        Returns
        - completed advancement
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file java.nio.file.Paths

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.net import URI
from java.nio.file import *
from java.nio.file.spi import FileSystemProvider
from typing import Any, Callable, Iterable, Tuple


class Paths:

    @staticmethod
    def get(first: str, *more: Tuple[str, ...]) -> "Path":
        """
        Converts a path string, or a sequence of strings that when joined form
        a path string, to a `Path`.

        Arguments
        - first: the path string or initial part of the path string
        - more: additional strings to be joined to form the path string

        Returns
        - the resulting `Path`

        Raises
        - InvalidPathException: if the path string cannot be converted to a `Path`

        See
        - Path.of(String,String...)

        Unknown Tags
        - This method simply invokes Path.of(String,String...)
        Path.of(String, String...) with the given parameters.
        """
        ...


    @staticmethod
    def get(uri: "URI") -> "Path":
        """
        Converts the given URI to a Path object.

        Arguments
        - uri: the URI to convert

        Returns
        - the resulting `Path`

        Raises
        - IllegalArgumentException: if preconditions on the `uri` parameter do not hold. The
                 format of the URI is provider specific.
        - FileSystemNotFoundException: The file system, identified by the URI, does not exist and
                 cannot be created automatically, or the provider identified by
                 the URI's scheme component is not installed
        - SecurityException: if a security manager is installed and it denies an unspecified
                 permission to access the file system

        See
        - Path.of(URI)

        Unknown Tags
        - This method simply invokes Path.of(URI) Path.of(URI) with the
        given parameter.
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.ForwardingNavigableSet

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.collect import *
from java.util import Iterator
from java.util import NavigableSet
from java.util import SortedSet
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class ForwardingNavigableSet(ForwardingSortedSet, NavigableSet):
    """
    A navigable set which forwards all its method calls to another navigable set. Subclasses should
    override one or more methods to modify the behavior of the backing set as desired per the <a
    href="http://en.wikipedia.org/wiki/Decorator_pattern">decorator pattern</a>.
    
    **Warning:** The methods of `ForwardingNavigableSet` forward *indiscriminately*
    to the methods of the delegate. For example, overriding .add alone *will not* change
    the behavior of .addAll, which can lead to unexpected behavior. In this case, you should
    override `addAll` as well, either providing your own implementation, or delegating to the
    provided `standardAddAll` method.
    
    **`default` method warning:** This class does *not* forward calls to `default` methods. Instead, it inherits their default implementations. When those implementations
    invoke methods, they invoke methods on the `ForwardingNavigableSet`.
    
    Each of the `standard` methods uses the set's comparator (or the natural ordering of the
    elements, if there is no comparator) to test element equality. As a result, if the comparator is
    not consistent with equals, some of the standard implementations may violate the `Set`
    contract.
    
    The `standard` methods and the collection views they return are not guaranteed to be
    thread-safe, even when all of the methods that they depend on are thread-safe.

    Author(s)
    - Louis Wasserman

    Since
    - 12.0
    """

    def lower(self, e: "E") -> "E":
        ...


    def floor(self, e: "E") -> "E":
        ...


    def ceiling(self, e: "E") -> "E":
        ...


    def higher(self, e: "E") -> "E":
        ...


    def pollFirst(self) -> "E":
        ...


    def pollLast(self) -> "E":
        ...


    def descendingSet(self) -> "NavigableSet"["E"]:
        ...


    def descendingIterator(self) -> Iterator["E"]:
        ...


    def subSet(self, fromElement: "E", fromInclusive: bool, toElement: "E", toInclusive: bool) -> "NavigableSet"["E"]:
        ...


    def headSet(self, toElement: "E", inclusive: bool) -> "NavigableSet"["E"]:
        ...


    def tailSet(self, fromElement: "E", inclusive: bool) -> "NavigableSet"["E"]:
        ...



"""
Python module generated from Java source file org.bukkit.permissions.Permissible

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.permissions import *
from org.bukkit.plugin import Plugin
from typing import Any, Callable, Iterable, Tuple


class Permissible(ServerOperator):
    """
    Represents an object that may be assigned permissions
    """

    def isPermissionSet(self, name: str) -> bool:
        """
        Checks if this object contains an override for the specified
        permission, by fully qualified name

        Arguments
        - name: Name of the permission

        Returns
        - True if the permission is set, otherwise False
        """
        ...


    def isPermissionSet(self, perm: "Permission") -> bool:
        """
        Checks if this object contains an override for the specified Permission

        Arguments
        - perm: Permission to check

        Returns
        - True if the permission is set, otherwise False
        """
        ...


    def hasPermission(self, name: str) -> bool:
        """
        Gets the value of the specified permission, if set.
        
        If a permission override is not set on this object, the default value
        of the permission will be returned.

        Arguments
        - name: Name of the permission

        Returns
        - Value of the permission
        """
        ...


    def hasPermission(self, perm: "Permission") -> bool:
        """
        Gets the value of the specified permission, if set.
        
        If a permission override is not set on this object, the default value
        of the permission will be returned

        Arguments
        - perm: Permission to get

        Returns
        - Value of the permission
        """
        ...


    def addAttachment(self, plugin: "Plugin", name: str, value: bool) -> "PermissionAttachment":
        """
        Adds a new PermissionAttachment with a single permission by
        name and value

        Arguments
        - plugin: Plugin responsible for this attachment, may not be null
            or disabled
        - name: Name of the permission to attach
        - value: Value of the permission

        Returns
        - The PermissionAttachment that was just created
        """
        ...


    def addAttachment(self, plugin: "Plugin") -> "PermissionAttachment":
        """
        Adds a new empty PermissionAttachment to this object

        Arguments
        - plugin: Plugin responsible for this attachment, may not be null
            or disabled

        Returns
        - The PermissionAttachment that was just created
        """
        ...


    def addAttachment(self, plugin: "Plugin", name: str, value: bool, ticks: int) -> "PermissionAttachment":
        """
        Temporarily adds a new PermissionAttachment with a single
        permission by name and value

        Arguments
        - plugin: Plugin responsible for this attachment, may not be null
            or disabled
        - name: Name of the permission to attach
        - value: Value of the permission
        - ticks: Amount of ticks to automatically remove this attachment
            after

        Returns
        - The PermissionAttachment that was just created
        """
        ...


    def addAttachment(self, plugin: "Plugin", ticks: int) -> "PermissionAttachment":
        """
        Temporarily adds a new empty PermissionAttachment to this
        object

        Arguments
        - plugin: Plugin responsible for this attachment, may not be null
            or disabled
        - ticks: Amount of ticks to automatically remove this attachment
            after

        Returns
        - The PermissionAttachment that was just created
        """
        ...


    def removeAttachment(self, attachment: "PermissionAttachment") -> None:
        """
        Removes the given PermissionAttachment from this object

        Arguments
        - attachment: Attachment to remove

        Raises
        - IllegalArgumentException: Thrown when the specified attachment
            isn't part of this object
        """
        ...


    def recalculatePermissions(self) -> None:
        """
        Recalculates the permissions for this object, if the attachments have
        changed values.
        
        This should very rarely need to be called from a plugin.
        """
        ...


    def getEffectivePermissions(self) -> set["PermissionAttachmentInfo"]:
        """
        Gets a set containing all of the permissions currently in effect by
        this object

        Returns
        - Set of currently effective permissions
        """
        ...



"""
Python module generated from Java source file java.nio.charset.StandardCharsets

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.nio.charset import *
from typing import Any, Callable, Iterable, Tuple


class StandardCharsets:
    """
    Constant definitions for the standard Charset charsets. These
    charsets are guaranteed to be available on every implementation of the Java
    platform.

    See
    - <a href="Charset.html.standard">Standard Charsets</a>

    Since
    - 1.7
    """

    US_ASCII = sun.nio.cs.US_ASCII.INSTANCE
    """
    Seven-bit ASCII, also known as ISO646-US, also known as the
    Basic Latin block of the Unicode character set.
    """
    ISO_8859_1 = sun.nio.cs.ISO_8859_1.INSTANCE
    """
    ISO Latin Alphabet No. 1, also known as ISO-LATIN-1.
    """
    UTF_8 = sun.nio.cs.UTF_8.INSTANCE
    """
    Eight-bit UCS Transformation Format.
    """
    UTF_16BE = sun.nio.cs.UTF_16BE()
    """
    Sixteen-bit UCS Transformation Format, big-endian byte order.
    """
    UTF_16LE = sun.nio.cs.UTF_16LE()
    """
    Sixteen-bit UCS Transformation Format, little-endian byte order.
    """
    UTF_16 = sun.nio.cs.UTF_16()
    """
    Sixteen-bit UCS Transformation Format, byte order identified by an
    optional byte-order mark.
    """



"""
Python module generated from Java source file com.google.common.graph.AbstractBaseGraph

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.collect import ImmutableSet
from com.google.common.collect import Iterators
from com.google.common.collect import Sets
from com.google.common.collect import UnmodifiableIterator
from com.google.common.graph import *
from com.google.common.math import IntMath
from com.google.common.primitives import Ints
from java.util import AbstractSet
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class AbstractBaseGraph(BaseGraph):
    """
    This class provides a skeletal implementation of BaseGraph.
    
    The methods implemented in this class should not be overridden unless the subclass admits a
    more efficient implementation.
    
    Type `<N>`: Node parameter type

    Author(s)
    - James Sexton
    """

    def edges(self) -> set["EndpointPair"["N"]]:
        """
        An implementation of BaseGraph.edges() defined in terms of Graph.nodes() and
        .successors(Object).
        """
        ...


    def incidentEdgeOrder(self) -> "ElementOrder"["N"]:
        ...


    def incidentEdges(self, node: "N") -> set["EndpointPair"["N"]]:
        ...


    def degree(self, node: "N") -> int:
        ...


    def inDegree(self, node: "N") -> int:
        ...


    def outDegree(self, node: "N") -> int:
        ...


    def hasEdgeConnecting(self, nodeU: "N", nodeV: "N") -> bool:
        ...


    def hasEdgeConnecting(self, endpoints: "EndpointPair"["N"]) -> bool:
        ...



"""
Python module generated from Java source file java.util.function.IntFunction

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util.function import *
from typing import Any, Callable, Iterable, Tuple


class IntFunction:
    """
    Represents a function that accepts an int-valued argument and produces a
    result.  This is the `int`-consuming primitive specialization for
    Function.
    
    This is a <a href="package-summary.html">functional interface</a>
    whose functional method is .apply(int).
    
    Type `<R>`: the type of the result of the function

    See
    - Function

    Since
    - 1.8
    """

    def apply(self, value: int) -> "R":
        """
        Applies this function to the given argument.

        Arguments
        - value: the function argument

        Returns
        - the function result
        """
        ...



"""
Python module generated from Java source file org.bukkit.inventory.meta.KnowledgeBookMeta

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import NamespacedKey
from org.bukkit.inventory.meta import *
from typing import Any, Callable, Iterable, Tuple


class KnowledgeBookMeta(ItemMeta):

    def hasRecipes(self) -> bool:
        """
        Checks for the existence of recipes in the book.

        Returns
        - True if the book has recipes
        """
        ...


    def getRecipes(self) -> list["NamespacedKey"]:
        """
        Gets all the recipes in the book.

        Returns
        - list of all the recipes in the book
        """
        ...


    def setRecipes(self, recipes: list["NamespacedKey"]) -> None:
        """
        Clears the existing book recipes, and sets the book to use the provided
        recipes.

        Arguments
        - recipes: A list of recipes to set the book to use
        """
        ...


    def addRecipe(self, *recipes: Tuple["NamespacedKey", ...]) -> None:
        """
        Adds new recipe to the end of the book.

        Arguments
        - recipes: A list of recipe keys
        """
        ...


    def clone(self) -> "KnowledgeBookMeta":
        ...



"""
Python module generated from Java source file org.bukkit.BlockChangeDelegate

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import *
from org.bukkit.block.data import BlockData
from typing import Any, Callable, Iterable, Tuple


class BlockChangeDelegate:
    """
    A delegate for handling block changes. This serves as a direct interface
    between generation algorithms in the server implementation and utilizing
    code.
    """

    def setBlockData(self, x: int, y: int, z: int, blockData: "BlockData") -> bool:
        """
        Set a block data at the specified coordinates.

        Arguments
        - x: X coordinate
        - y: Y coordinate
        - z: Z coordinate
        - blockData: Block data

        Returns
        - True if the block was set successfully
        """
        ...


    def getBlockData(self, x: int, y: int, z: int) -> "BlockData":
        """
        Get the block data at the location.

        Arguments
        - x: X coordinate
        - y: Y coordinate
        - z: Z coordinate

        Returns
        - The block data
        """
        ...


    def getHeight(self) -> int:
        """
        Gets the height of the world.

        Returns
        - Height of the world
        """
        ...


    def isEmpty(self, x: int, y: int, z: int) -> bool:
        """
        Checks if the specified block is empty (air) or not.

        Arguments
        - x: X coordinate
        - y: Y coordinate
        - z: Z coordinate

        Returns
        - True if the block is considered empty.
        """
        ...



"""
Python module generated from Java source file com.google.common.util.concurrent.InterruptibleTask

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import VisibleForTesting
from com.google.common.util.concurrent import *
from com.google.j2objc.annotations import ReflectionSupport
from java.util.concurrent.atomic import AtomicReference
from java.util.concurrent.locks import AbstractOwnableSynchronizer
from java.util.concurrent.locks import LockSupport
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class InterruptibleTask(AtomicReference, Runnable):

    def run(self) -> None:
        ...


    def toString(self) -> str:
        ...



"""
Python module generated from Java source file org.bukkit.configuration.serialization.DelegateDeserialization

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.configuration.serialization import *
from typing import Any, Callable, Iterable, Tuple


class DelegateDeserialization:
    """
    Applies to a ConfigurationSerializable that will delegate all
    deserialization to another ConfigurationSerializable.
    """

    def value(self) -> type["ConfigurationSerializable"]:
        """
        Which class should be used as a delegate for this classes
        deserialization

        Returns
        - Delegate class
        """
        ...



"""
Python module generated from Java source file org.bukkit.block.spawner.SpawnRule

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from org.bukkit.block.spawner import *
from org.bukkit.configuration.serialization import ConfigurationSerializable
from org.bukkit.configuration.serialization import SerializableAs
from typing import Any, Callable, Iterable, Tuple


class SpawnRule(Cloneable, ConfigurationSerializable):
    """
    Represents a spawn rule that controls what conditions an entity from a
    monster spawner can spawn.
    """

    def __init__(self, minBlockLight: int, maxBlockLight: int, minSkyLight: int, maxSkyLight: int):
        """
        Constructs a new SpawnRule.

        Arguments
        - minBlockLight: The minimum (inclusive) block light required for
        spawning to succeed.
        - maxBlockLight: The maximum (inclusive) block light required for
        spawning to succeed.
        - minSkyLight: The minimum (inclusive) sky light required for
        spawning to succeed.
        - maxSkyLight: The maximum (inclusive) sky light required for
        spawning to succeed.
        """
        ...


    def getMinBlockLight(self) -> int:
        """
        Gets the minimum (inclusive) block light required for spawning to
        succeed.

        Returns
        - minimum block light
        """
        ...


    def setMinBlockLight(self, minBlockLight: int) -> None:
        """
        Sets the minimum (inclusive) block light required for spawning to
        succeed.

        Arguments
        - minBlockLight: minimum block light
        """
        ...


    def getMaxBlockLight(self) -> int:
        """
        Gets the maximum (inclusive) block light required for spawning to
        succeed.

        Returns
        - maximum block light
        """
        ...


    def setMaxBlockLight(self, maxBlockLight: int) -> None:
        """
        Sets the maximum (inclusive) block light required for spawning to
        succeed.

        Arguments
        - maxBlockLight: maximum block light
        """
        ...


    def getMinSkyLight(self) -> int:
        """
        Gets the minimum (inclusive) sky light required for spawning to succeed.

        Returns
        - minimum sky light
        """
        ...


    def setMinSkyLight(self, minSkyLight: int) -> None:
        """
        Sets the minimum (inclusive) sky light required for spawning to succeed.

        Arguments
        - minSkyLight: minimum sky light
        """
        ...


    def getMaxSkyLight(self) -> int:
        """
        Gets the maximum (inclusive) sky light required for spawning to succeed.

        Returns
        - maximum sky light
        """
        ...


    def setMaxSkyLight(self, maxSkyLight: int) -> None:
        """
        Sets the maximum (inclusive) sky light required for spawning to succeed.

        Arguments
        - maxSkyLight: maximum sky light
        """
        ...


    def equals(self, obj: "Object") -> bool:
        ...


    def hashCode(self) -> int:
        ...


    def clone(self) -> "SpawnRule":
        ...


    def serialize(self) -> dict[str, "Object"]:
        ...


    @staticmethod
    def deserialize(args: dict[str, "Object"]) -> "SpawnRule":
        ...



"""
Python module generated from Java source file com.google.common.io.ByteProcessor

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.io import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.errorprone.annotations import DoNotMock
from java.io import IOException
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class ByteProcessor:
    """
    A callback interface to process bytes from a stream.
    
    .processBytes will be called for each chunk of data that is read, and should return
    `False` when you want to stop processing.

    Author(s)
    - Chris Nokleberg

    Since
    - 1.0
    """

    def processBytes(self, buf: list[int], off: int, len: int) -> bool:
        """
        This method will be called for each chunk of bytes in an input stream. The implementation
        should process the bytes from `buf[off]` through `buf[off + len - 1]` (inclusive).

        Arguments
        - buf: the byte array containing the data to process
        - off: the initial offset into the array
        - len: the length of data to be processed

        Returns
        - True to continue processing, False to stop
        """
        ...


    def getResult(self) -> "T":
        """
        Return the result of processing all the bytes.
        """
        ...



"""
Python module generated from Java source file com.google.gson.internal.NumberLimits

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson.internal import *
from java.math import BigDecimal
from java.math import BigInteger
from typing import Any, Callable, Iterable, Tuple


class NumberLimits:
    """
    This class enforces limits on numbers parsed from JSON to avoid potential performance problems
    when extremely large numbers are used.
    """

    @staticmethod
    def parseBigDecimal(s: str) -> "BigDecimal":
        ...


    @staticmethod
    def parseBigInteger(s: str) -> "BigInteger":
        ...



"""
Python module generated from Java source file java.util.Iterator

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import *
from java.util.function import Consumer
from typing import Any, Callable, Iterable, Tuple


class Iterator:
    """
    An iterator over a collection.  `Iterator` takes the place of
    Enumeration in the Java Collections Framework.  Iterators
    differ from enumerations in two ways:
    
    
         -  Iterators allow the caller to remove elements from the
              underlying collection during the iteration with well-defined
              semantics.
         -  Method names have been improved.
    
    
    This interface is a member of the
    <a href="/java.base/java/util/package-summary.html#CollectionsFramework">
    Java Collections Framework</a>.
    
    Type `<E>`: the type of elements returned by this iterator

    Author(s)
    - Josh Bloch

    See
    - Iterable

    Since
    - 1.2

    Unknown Tags
    - An Enumeration can be converted into an `Iterator` by
    using the Enumeration.asIterator method.
    """

    def hasNext(self) -> bool:
        """
        Returns `True` if the iteration has more elements.
        (In other words, returns `True` if .next would
        return an element rather than throwing an exception.)

        Returns
        - `True` if the iteration has more elements
        """
        ...


    def next(self) -> "E":
        """
        Returns the next element in the iteration.

        Returns
        - the next element in the iteration

        Raises
        - NoSuchElementException: if the iteration has no more elements
        """
        ...


    def remove(self) -> None:
        """
        Removes from the underlying collection the last element returned
        by this iterator (optional operation).  This method can be called
        only once per call to .next.
        
        The behavior of an iterator is unspecified if the underlying collection
        is modified while the iteration is in progress in any way other than by
        calling this method, unless an overriding class has specified a
        concurrent modification policy.
        
        The behavior of an iterator is unspecified if this method is called
        after a call to the .forEachRemaining forEachRemaining method.

        Raises
        - UnsupportedOperationException: if the `remove`
                operation is not supported by this iterator
        - IllegalStateException: if the `next` method has not
                yet been called, or the `remove` method has already
                been called after the last call to the `next`
                method

        Unknown Tags
        - The default implementation throws an instance of
        UnsupportedOperationException and performs no other action.
        """
        ...


    def forEachRemaining(self, action: "Consumer"["E"]) -> None:
        """
        Performs the given action for each remaining element until all elements
        have been processed or the action throws an exception.  Actions are
        performed in the order of iteration, if that order is specified.
        Exceptions thrown by the action are relayed to the caller.
        
        The behavior of an iterator is unspecified if the action modifies the
        collection in any way (even by calling the .remove remove method
        or other mutator methods of `Iterator` subtypes),
        unless an overriding class has specified a concurrent modification policy.
        
        Subsequent behavior of an iterator is unspecified if the action throws an
        exception.

        Arguments
        - action: The action to be performed for each element

        Raises
        - NullPointerException: if the specified action is null

        Since
        - 1.8

        Unknown Tags
        - The default implementation behaves as if:
        ````while (hasNext())
                action.accept(next());````
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.ForwardingSortedSet

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from java.util import Comparator
from java.util import Iterator
from java.util import NoSuchElementException
from java.util import SortedSet
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class ForwardingSortedSet(ForwardingSet, SortedSet):
    """
    A sorted set which forwards all its method calls to another sorted set. Subclasses should
    override one or more methods to modify the behavior of the backing sorted set as desired per the
    <a href="http://en.wikipedia.org/wiki/Decorator_pattern">decorator pattern</a>.
    
    **Warning:** The methods of `ForwardingSortedSet` forward *indiscriminately* to
    the methods of the delegate. For example, overriding .add alone *will not* change
    the behavior of .addAll, which can lead to unexpected behavior. In this case, you should
    override `addAll` as well, either providing your own implementation, or delegating to the
    provided `standardAddAll` method.
    
    **`default` method warning:** This class does *not* forward calls to `default` methods. Instead, it inherits their default implementations. When those implementations
    invoke methods, they invoke methods on the `ForwardingSortedSet`.
    
    Each of the `standard` methods, where appropriate, uses the set's comparator (or the
    natural ordering of the elements, if there is no comparator) to test element equality. As a
    result, if the comparator is not consistent with equals, some of the standard implementations may
    violate the `Set` contract.
    
    The `standard` methods and the collection views they return are not guaranteed to be
    thread-safe, even when all of the methods that they depend on are thread-safe.

    Author(s)
    - Louis Wasserman

    Since
    - 2.0
    """

    def comparator(self) -> "Comparator"["E"]:
        ...


    def first(self) -> "E":
        ...


    def headSet(self, toElement: "E") -> "SortedSet"["E"]:
        ...


    def last(self) -> "E":
        ...


    def subSet(self, fromElement: "E", toElement: "E") -> "SortedSet"["E"]:
        ...


    def tailSet(self, fromElement: "E") -> "SortedSet"["E"]:
        ...



"""
Python module generated from Java source file org.joml.Vector2Lc

Java source file obtained from artifact joml version 1.10.8

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.joml import *
from typing import Any, Callable, Iterable, Tuple


class Vector2Lc:
    """
    Interface to a read-only view of a 2-dimensional vector of integers.

    Author(s)
    - Kai Burjack
    """

    def x(self) -> int:
        """
        Returns
        - the value of the x component
        """
        ...


    def y(self) -> int:
        """
        Returns
        - the value of the y component
        """
        ...


    def get(self, buffer: "ByteBuffer") -> "ByteBuffer":
        """
        Store this vector into the supplied ByteBuffer at the current
        buffer ByteBuffer.position() position.
        
        This method will not increment the position of the given ByteBuffer.
        
        In order to specify the offset into the ByteBuffer at which the vector is
        stored, use .get(int, ByteBuffer), taking the absolute position
        as parameter.

        Arguments
        - buffer: will receive the values of this vector in `x, y` order

        Returns
        - the passed in buffer

        See
        - .get(int, ByteBuffer)
        """
        ...


    def get(self, index: int, buffer: "ByteBuffer") -> "ByteBuffer":
        """
        Store this vector into the supplied ByteBuffer starting at the
        specified absolute buffer position/index.
        
        This method will not increment the position of the given ByteBuffer.

        Arguments
        - index: the absolute position into the ByteBuffer
        - buffer: will receive the values of this vector in `x, y` order

        Returns
        - the passed in buffer
        """
        ...


    def get(self, buffer: "LongBuffer") -> "LongBuffer":
        """
        Store this vector into the supplied LongBuffer at the current
        buffer LongBuffer.position() position.
        
        This method will not increment the position of the given IntBuffer.
        
        In order to specify the offset into the IntBuffer at which the vector is
        stored, use .get(int, LongBuffer), taking the absolute position as
        parameter.

        Arguments
        - buffer: will receive the values of this vector in `x, y` order

        Returns
        - the passed in buffer

        See
        - .get(int, LongBuffer)
        """
        ...


    def get(self, index: int, buffer: "LongBuffer") -> "LongBuffer":
        """
        Store this vector into the supplied LongBuffer starting at the
        specified absolute buffer position/index.
        
        This method will not increment the position of the given IntBuffer.

        Arguments
        - index: the absolute position into the IntBuffer
        - buffer: will receive the values of this vector in `x, y` order

        Returns
        - the passed in buffer
        """
        ...


    def getToAddress(self, address: int) -> "Vector2Lc":
        """
        Store this vector at the given off-heap memory address.
        
        This method will throw an UnsupportedOperationException when JOML is used with `-Djoml.nounsafe`.
        
        *This method is unsafe as it can result in a crash of the JVM process when the specified address range does not belong to this process.*

        Arguments
        - address: the off-heap address where to store this vector

        Returns
        - this
        """
        ...


    def sub(self, v: "Vector2Lc", dest: "Vector2L") -> "Vector2L":
        """
        Subtract the supplied vector from this one and store the result in
        `dest`.

        Arguments
        - v: the vector to subtract
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def sub(self, x: int, y: int, dest: "Vector2L") -> "Vector2L":
        """
        Decrement the components of this vector by the given values and store the
        result in `dest`.

        Arguments
        - x: the x component to subtract
        - y: the y component to subtract
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def lengthSquared(self) -> int:
        """
        Return the length squared of this vector.

        Returns
        - the length squared
        """
        ...


    def length(self) -> float:
        """
        Return the length of this vector.

        Returns
        - the length
        """
        ...


    def distance(self, v: "Vector2Lc") -> float:
        """
        Return the distance between this Vector and `v`.

        Arguments
        - v: the other vector

        Returns
        - the distance
        """
        ...


    def distance(self, x: int, y: int) -> float:
        """
        Return the distance between `this` vector and `(x, y)`.

        Arguments
        - x: the x component of the other vector
        - y: the y component of the other vector

        Returns
        - the euclidean distance
        """
        ...


    def distanceSquared(self, v: "Vector2Lc") -> int:
        """
        Return the square of the distance between this vector and `v`.

        Arguments
        - v: the other vector

        Returns
        - the squared of the distance
        """
        ...


    def distanceSquared(self, x: int, y: int) -> int:
        """
        Return the square of the distance between `this` vector and
        `(x, y)`.

        Arguments
        - x: the x component of the other vector
        - y: the y component of the other vector

        Returns
        - the square of the distance
        """
        ...


    def gridDistance(self, v: "Vector2Lc") -> int:
        """
        Return the grid distance in between (aka 1-Norm, Minkowski or Manhattan distance)
        `(x, y)`.

        Arguments
        - v: the other vector

        Returns
        - the grid distance
        """
        ...


    def gridDistance(self, x: int, y: int) -> int:
        """
        Return the grid distance in between (aka 1-Norm, Minkowski or Manhattan distance)
        `(x, y)`.

        Arguments
        - x: the x component of the other vector
        - y: the y component of the other vector

        Returns
        - the grid distance
        """
        ...


    def add(self, v: "Vector2Lc", dest: "Vector2L") -> "Vector2L":
        """
        Add the supplied vector to this one and store the result in
        `dest`.

        Arguments
        - v: the vector to add
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def add(self, x: int, y: int, dest: "Vector2L") -> "Vector2L":
        """
        Increment the components of this vector by the given values and store the
        result in `dest`.

        Arguments
        - x: the x component to add
        - y: the y component to add
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def mul(self, scalar: int, dest: "Vector2L") -> "Vector2L":
        """
        Multiply all components of this Vector2Lc by the given scalar
        value and store the result in `dest`.

        Arguments
        - scalar: the scalar to multiply this vector by
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def mul(self, v: "Vector2Lc", dest: "Vector2L") -> "Vector2L":
        """
        Multiply the supplied vector by this one and store the result in
        `dest`.

        Arguments
        - v: the vector to multiply
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def mul(self, x: int, y: int, dest: "Vector2L") -> "Vector2L":
        """
        Multiply the components of this vector by the given values and store the
        result in `dest`.

        Arguments
        - x: the x component to multiply
        - y: the y component to multiply
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def div(self, scalar: float, dest: "Vector2L") -> "Vector2L":
        """
        Divide all components of this vector by the given scalar value
        and store the result in `dest`.

        Arguments
        - scalar: the scalar to divide by
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def div(self, scalar: int, dest: "Vector2L") -> "Vector2L":
        """
        Divide all components of this vector by the given scalar value
        and store the result in `dest`.

        Arguments
        - scalar: the scalar to divide by
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def negate(self, dest: "Vector2L") -> "Vector2L":
        """
        Negate this vector and store the result in `dest`.

        Arguments
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def min(self, v: "Vector2Lc", dest: "Vector2L") -> "Vector2L":
        """
        Set the components of `dest` to be the component-wise minimum of this and the other vector.

        Arguments
        - v: the other vector
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def max(self, v: "Vector2Lc", dest: "Vector2L") -> "Vector2L":
        """
        Set the components of `dest` to be the component-wise maximum of this and the other vector.

        Arguments
        - v: the other vector
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def maxComponent(self) -> int:
        """
        Determine the component with the biggest absolute value.

        Returns
        - the component index, within `[0..1]`
        """
        ...


    def minComponent(self) -> int:
        """
        Determine the component with the smallest (towards zero) absolute value.

        Returns
        - the component index, within `[0..1]`
        """
        ...


    def absolute(self, dest: "Vector2L") -> "Vector2L":
        """
        Compute the absolute of each of this vector's components
        and store the result into `dest`.

        Arguments
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def get(self, component: int) -> int:
        """
        Get the value of the specified component of this vector.

        Arguments
        - component: the component, within `[0..1]`

        Returns
        - the value

        Raises
        - IllegalArgumentException: if `component` is not within `[0..1]`
        """
        ...


    def equals(self, x: int, y: int) -> bool:
        """
        Compare the vector components of `this` vector with the given `(x, y)`
        and return whether all of them are equal.

        Arguments
        - x: the x component to compare to
        - y: the y component to compare to

        Returns
        - `True` if all the vector components are equal
        """
        ...



"""
Python module generated from Java source file org.bukkit.block.data.type.MossyCarpet

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.block import BlockFace
from org.bukkit.block.data import BlockData
from org.bukkit.block.data.type import *
from typing import Any, Callable, Iterable, Tuple


class MossyCarpet(BlockData):
    """
    This class encompasses the 'north', 'east', 'south', 'west', height flags
    which are used to set the height of a face.
    
    'bottom' denotes whether this is a bottom block.
    """

    def isBottom(self) -> bool:
        """
        Gets the value of the 'bottom' property.

        Returns
        - the 'bottom' value
        """
        ...


    def setBottom(self, bottom: bool) -> None:
        """
        Sets the value of the 'bottom' property.

        Arguments
        - bottom: the new 'bottom' value
        """
        ...


    def getHeight(self, face: "BlockFace") -> "Height":
        """
        Gets the height of the specified face.

        Arguments
        - face: to check

        Returns
        - if face is enabled
        """
        ...


    def setHeight(self, face: "BlockFace", height: "Height") -> None:
        """
        Set the height of the specified face.

        Arguments
        - face: to set
        - height: the height
        """
        ...


    class Height(Enum):
        """
        The different heights a face may have.
        """

        NONE = 0
        """
        Not present.
        """
        LOW = 1
        """
        Low face present.
        """
        TALL = 2
        """
        Tall face present.
        """



"""
Python module generated from Java source file org.bukkit.event.server.ServiceEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.event.server import *
from org.bukkit.plugin import RegisteredServiceProvider
from typing import Any, Callable, Iterable, Tuple


class ServiceEvent(ServerEvent):
    """
    An event relating to a registered service. This is called in a org.bukkit.plugin.ServicesManager
    """

    def __init__(self, provider: "RegisteredServiceProvider"[Any]):
        ...


    def getProvider(self) -> "RegisteredServiceProvider"[Any]:
        ...



"""
Python module generated from Java source file org.bukkit.event.hanging.HangingBreakEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.entity import Hanging
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.hanging import *
from typing import Any, Callable, Iterable, Tuple


class HangingBreakEvent(HangingEvent, Cancellable):
    """
    Triggered when a hanging entity is removed
    """

    def __init__(self, hanging: "Hanging", cause: "HangingBreakEvent.RemoveCause"):
        ...


    def getCause(self) -> "HangingBreakEvent.RemoveCause":
        """
        Gets the cause for the hanging entity's removal

        Returns
        - the RemoveCause for the hanging entity's removal
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...


    class RemoveCause(Enum):
        """
        An enum to specify the cause of the removal
        """

        ENTITY = 0
        """
        Removed by an entity
        """
        EXPLOSION = 1
        """
        Removed by an explosion
        """
        OBSTRUCTION = 2
        """
        Removed by placing a block on it
        """
        PHYSICS = 3
        """
        Removed by destroying the block behind it, etc
        """
        DEFAULT = 4
        """
        Removed by an uncategorised cause
        """



"""
Python module generated from Java source file org.bukkit.map.MapFont

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import ChatColor
from org.bukkit.map import *
from typing import Any, Callable, Iterable, Tuple


class MapFont:
    """
    Represents a bitmap font drawable to a map.
    """

    def setChar(self, ch: str, sprite: "CharacterSprite") -> None:
        """
        Set the sprite for a given character.

        Arguments
        - ch: The character to set the sprite for.
        - sprite: The CharacterSprite to set.

        Raises
        - IllegalStateException: if this font is static.
        """
        ...


    def getChar(self, ch: str) -> "CharacterSprite":
        """
        Get the sprite for a given character.

        Arguments
        - ch: The character to get the sprite for.

        Returns
        - The CharacterSprite associated with the character, or null if
            there is none.
        """
        ...


    def getWidth(self, text: str) -> int:
        """
        Get the width of the given text as it would be rendered using this
        font.

        Arguments
        - text: The text.

        Returns
        - The width in pixels.
        """
        ...


    def getHeight(self) -> int:
        """
        Get the height of this font.

        Returns
        - The height of the font.
        """
        ...


    def isValid(self, text: str) -> bool:
        """
        Check whether the given text is valid.

        Arguments
        - text: The text.

        Returns
        - True if the string contains only defined characters, False
            otherwise.
        """
        ...


    class CharacterSprite:
        """
        Represents the graphics for a single character in a MapFont.
        """

        def __init__(self, width: int, height: int, data: list[bool]):
            ...


        def get(self, row: int, col: int) -> bool:
            """
            Get the value of a pixel of the character.

            Arguments
            - row: The row, in the range [0,8).
            - col: The column, in the range [0,8).

            Returns
            - True if the pixel is solid, False if transparent.
            """
            ...


        def getWidth(self) -> int:
            """
            Get the width of the character sprite.

            Returns
            - The width of the character.
            """
            ...


        def getHeight(self) -> int:
            """
            Get the height of the character sprite.

            Returns
            - The height of the character.
            """
            ...



"""
Python module generated from Java source file org.bukkit.entity.Sittable

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class Sittable:
    """
    An animal that can sit still.
    """

    def isSitting(self) -> bool:
        """
        Checks if this animal is sitting

        Returns
        - True if sitting
        """
        ...


    def setSitting(self, sitting: bool) -> None:
        """
        Sets if this animal is sitting. Will remove any path that the animal
        was following beforehand.

        Arguments
        - sitting: True if sitting
        """
        ...



"""
Python module generated from Java source file org.bukkit.entity.SpectralArrow

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class SpectralArrow(AbstractArrow):
    """
    Represents a spectral arrow.
    """

    def getGlowingTicks(self) -> int:
        """
        Returns the amount of time that this arrow will apply
        the glowing effect for.

        Returns
        - the glowing effect ticks
        """
        ...


    def setGlowingTicks(self, duration: int) -> None:
        """
        Sets the amount of time to apply the glowing effect for.

        Arguments
        - duration: the glowing effect ticks
        """
        ...



from .TranslationProvider import TranslationProvider
from .TranslatableComponent import TranslatableComponent
from .TextComponent import TextComponent
from .SelectorComponent import SelectorComponent
from .ScoreComponent import ScoreComponent
from .Keybinds import Keybinds
from .KeybindComponent import KeybindComponent
from .ItemTag import ItemTag
from .HoverEvent import HoverEvent
from .ComponentStyleBuilder import ComponentStyleBuilder
from .ComponentStyle import ComponentStyle
from .ComponentBuilder import ComponentBuilder
from .ClickEvent import ClickEvent
from .BaseComponent import BaseComponent


"""
Python module generated from Java source file org.bukkit.plugin.messaging.PluginChannelDirection

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.plugin.messaging import *
from typing import Any, Callable, Iterable, Tuple


class PluginChannelDirection(Enum):
    """
    Represents the different directions a plugin channel may go.
    """

    INCOMING = 0
    """
    The plugin channel is being sent to the server from a client.
    """
    OUTGOING = 1
    """
    The plugin channel is being sent to a client from the server.
    """



"""
Python module generated from Java source file com.google.common.cache.LoadingCache

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.base import Function
from com.google.common.cache import *
from com.google.common.collect import ImmutableMap
from com.google.common.util.concurrent import ExecutionError
from com.google.common.util.concurrent import UncheckedExecutionException
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.util.concurrent import ConcurrentMap
from java.util.concurrent import ExecutionException
from typing import Any, Callable, Iterable, Tuple


class LoadingCache(Cache, Function):
    """
    A semi-persistent mapping from keys to values. Values are automatically loaded by the cache, and
    are stored in the cache until either evicted or manually invalidated. The common way to build
    instances is using CacheBuilder.
    
    Implementations of this interface are expected to be thread-safe, and can be safely accessed
    by multiple concurrent threads.
    
    When evaluated as a Function, a cache yields the same result as invoking .getUnchecked.
    
    Type `<K>`: the type of the cache's keys, which are not permitted to be null
    
    Type `<V>`: the type of the cache's values, which are not permitted to be null

    Author(s)
    - Charles Fry

    Since
    - 11.0
    """

    def get(self, key: "K") -> "V":
        """
        Returns the value associated with `key` in this cache, first loading that value if
        necessary. No observable state associated with this cache is modified until loading completes.
        
        If another call to .get or .getUnchecked is currently loading the value for
        `key`, simply waits for that thread to finish and returns its loaded value. Note that
        multiple threads can concurrently load values for distinct keys.
        
        Caches loaded by a CacheLoader will call CacheLoader.load to load new values
        into the cache. Newly loaded values are added to the cache using `Cache.asMap().putIfAbsent` after loading has completed; if another value was associated with
        `key` while the new value was loading then a removal notification will be sent for the
        new value.
        
        If the cache loader associated with this cache is known not to throw checked exceptions,
        then prefer .getUnchecked over this method.

        Raises
        - ExecutionException: if a checked exception was thrown while loading the value. (`ExecutionException` is thrown <a
            href="https://github.com/google/guava/wiki/CachesExplained#interruption">even if
            computation was interrupted by an `InterruptedException`</a>.)
        - UncheckedExecutionException: if an unchecked exception was thrown while loading the
            value
        - ExecutionError: if an error was thrown while loading the value
        """
        ...


    def getUnchecked(self, key: "K") -> "V":
        """
        Returns the value associated with `key` in this cache, first loading that value if
        necessary. No observable state associated with this cache is modified until loading completes.
        Unlike .get, this method does not throw a checked exception, and thus should only be
        used in situations where checked exceptions are not thrown by the cache loader.
        
        If another call to .get or .getUnchecked is currently loading the value for
        `key`, simply waits for that thread to finish and returns its loaded value. Note that
        multiple threads can concurrently load values for distinct keys.
        
        Caches loaded by a CacheLoader will call CacheLoader.load to load new values
        into the cache. Newly loaded values are added to the cache using `Cache.asMap().putIfAbsent` after loading has completed; if another value was associated with
        `key` while the new value was loading then a removal notification will be sent for the
        new value.
        
        **Warning:** this method silently converts checked exceptions to unchecked exceptions,
        and should not be used with cache loaders which throw checked exceptions. In such cases use
        .get instead.

        Raises
        - UncheckedExecutionException: if an exception was thrown while loading the value. (As
            explained in the last paragraph above, this should be an unchecked exception only.)
        - ExecutionError: if an error was thrown while loading the value
        """
        ...


    def getAll(self, keys: Iterable["K"]) -> "ImmutableMap"["K", "V"]:
        """
        Returns a map of the values associated with `keys`, creating or retrieving those values
        if necessary. The returned map contains entries that were already cached, combined with newly
        loaded entries; it will never contain null keys or values.
        
        Caches loaded by a CacheLoader will issue a single request to CacheLoader.loadAll for all keys which are not already present in the cache. All entries
        returned by CacheLoader.loadAll will be stored in the cache, over-writing any
        previously cached values. This method will throw an exception if CacheLoader.loadAll
        returns `null`, returns a map containing null keys or values, or fails to return an entry
        for each requested key.
        
        Note that duplicate elements in `keys`, as determined by Object.equals, will
        be ignored.

        Raises
        - ExecutionException: if a checked exception was thrown while loading the value. (`ExecutionException` is thrown <a
            href="https://github.com/google/guava/wiki/CachesExplained#interruption">even if
            computation was interrupted by an `InterruptedException`</a>.)
        - UncheckedExecutionException: if an unchecked exception was thrown while loading the
            values
        - ExecutionError: if an error was thrown while loading the values

        Since
        - 11.0
        """
        ...


    def apply(self, key: "K") -> "V":
        """
        Raises
        - UncheckedExecutionException: if an exception was thrown while loading the value. (As
            described in the documentation for .getUnchecked, `LoadingCache` should be
            used as a `Function` only with cache loaders that throw only unchecked exceptions.)

        Deprecated
        - Provided to satisfy the `Function` interface; use .get or .getUnchecked instead.
        """
        ...


    def refresh(self, key: "K") -> None:
        """
        Loads a new value for `key`, possibly asynchronously. While the new value is loading the
        previous value (if any) will continue to be returned by `get(key)` unless it is evicted.
        If the new value is loaded successfully it will replace the previous value in the cache; if an
        exception is thrown while refreshing the previous value will remain, *and the exception will
        be logged (using java.util.logging.Logger) and swallowed*.
        
        Caches loaded by a CacheLoader will call CacheLoader.reload if the cache
        currently contains a value for `key`, and CacheLoader.load otherwise. Loading is
        asynchronous only if CacheLoader.reload was overridden with an asynchronous
        implementation.
        
        Returns without doing anything if another thread is currently loading the value for `key`. If the cache loader associated with this cache performs refresh asynchronously then this
        method may return before refresh completes.

        Since
        - 11.0
        """
        ...


    def asMap(self) -> "ConcurrentMap"["K", "V"]:
        """
        
        
        **Note that although the view *is* modifiable, no method on the returned map will ever
        cause entries to be automatically loaded.**
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.player.PlayerHarvestBlockEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import Block
from org.bukkit.entity import Player
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.player import *
from org.bukkit.inventory import EquipmentSlot
from org.bukkit.inventory import ItemStack
from typing import Any, Callable, Iterable, Tuple


class PlayerHarvestBlockEvent(PlayerEvent, Cancellable):
    """
    This event is called whenever a player harvests a block.
    
    A 'harvest' is when a block drops an item (usually some sort of crop) and
    changes state, but is not broken in order to drop the item.
    
    This event is not called for when a block is broken, to handle that, listen
    for org.bukkit.event.block.BlockBreakEvent and
    org.bukkit.event.block.BlockDropItemEvent.
    """

    def __init__(self, player: "Player", harvestedBlock: "Block", hand: "EquipmentSlot", itemsHarvested: list["ItemStack"]):
        ...


    def __init__(self, player: "Player", harvestedBlock: "Block", itemsHarvested: list["ItemStack"]):
        ...


    def getHarvestedBlock(self) -> "Block":
        """
        Gets the block that is being harvested.

        Returns
        - The block that is being harvested
        """
        ...


    def getHand(self) -> "EquipmentSlot":
        """
        Get the hand used to harvest the block.

        Returns
        - the hand
        """
        ...


    def getItemsHarvested(self) -> list["ItemStack"]:
        """
        Gets a list of items that are being harvested from this block.

        Returns
        - A list of items that are being harvested from this block
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.generator.structure.StructureType

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Keyed
from org.bukkit import NamespacedKey
from org.bukkit import Registry
from org.bukkit.generator.structure import *
from org.bukkit.registry import RegistryAware
from typing import Any, Callable, Iterable, Tuple


class StructureType(Keyed, RegistryAware):
    """
    Represent a StructureType of a Structure.
    
    Listed structure types are present in the default server. Depending on the
    server there might be additional structure types present (for example
    structure types added by data packs), which can be received via
    Registry.STRUCTURE_TYPE.
    """

    BURIED_TREASURE = getStructureType("buried_treasure")
    DESERT_PYRAMID = getStructureType("desert_pyramid")
    END_CITY = getStructureType("end_city")
    FORTRESS = getStructureType("fortress")
    IGLOO = getStructureType("igloo")
    JIGSAW = getStructureType("jigsaw")
    JUNGLE_TEMPLE = getStructureType("jungle_temple")
    MINESHAFT = getStructureType("mineshaft")
    NETHER_FOSSIL = getStructureType("nether_fossil")
    OCEAN_MONUMENT = getStructureType("ocean_monument")
    OCEAN_RUIN = getStructureType("ocean_ruin")
    RUINED_PORTAL = getStructureType("ruined_portal")
    SHIPWRECK = getStructureType("shipwreck")
    STRONGHOLD = getStructureType("stronghold")
    SWAMP_HUT = getStructureType("swamp_hut")
    WOODLAND_MANSION = getStructureType("woodland_mansion")


    def getKey(self) -> "NamespacedKey":
        """
        See
        - .isRegistered()

        Deprecated
        - A key might not always be present, use .getKeyOrThrow() instead.
        """
        ...
